@@ -1,17 +1,14 @@
 <?php
 /**
+ * @copyright Copyright (c) 2016, ownCloud, Inc.
+ *
  * @author Bart Visscher <bartv@thisnet.nl>
- * @author Christian Kampka <christian@kampka.net>
- * @author Edward Crompton <edward.crompton@gmail.com>
- * @author Joas Schilling <nickvergessen@owncloud.com>
- * @author Jost Baron <Jost.Baron@gmx.de>
- * @author Lukas Reschke <lukas@owncloud.com>
+ * @author Joas Schilling <coding@schilljs.com>
+ * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
- * @author Philippe Le Brouster <plb@nebkha.net>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Victor Dubiniuk <dubiniuk@owncloud.com>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -42,8 +39,21 @@ if (version_compare(PHP_VERSION, '5.4.0') === -1) {
 	return;
 }
 
+// Show warning if PHP 7.1 is used as Nextcloud is not compatible with PHP 7.1 for now
+// @see https://github.com/nextcloud/docker-ci/issues/10
+if (version_compare(PHP_VERSION, '7.1.0') !== -1) {
+	echo 'This version of Nextcloud is not compatible with PHP 7.1.<br/>';
+	echo 'You are currently running ' . PHP_VERSION . '.';
+	return;
+}
+
+function exceptionHandler($exception) {
+	echo "An unhandled exception has been thrown:" . PHP_EOL;
+	echo $exception;
+	exit(1);
+}
 try {
-	require_once 'lib/base.php';
+	require_once __DIR__ . '/lib/base.php';
 
 	// set to run indefinitely if needed
 	set_time_limit(0);
@@ -53,29 +63,29 @@ try {
 		exit(0);
 	}
 
-	if (!OC_Util::runningOnWindows())  {
-		if (!function_exists('posix_getuid')) {
-			echo "The posix extensions are required - see http://php.net/manual/en/book.posix.php" . PHP_EOL;
-			exit(0);
-		}
-		$user = posix_getpwuid(posix_getuid());
-		$configUser = posix_getpwuid(fileowner(OC::$configDir . 'config.php'));
-		if ($user['name'] !== $configUser['name']) {
-			echo "Console has to be executed with the user that owns the file config/config.php" . PHP_EOL;
-			echo "Current user: " . $user['name'] . PHP_EOL;
-			echo "Owner of config.php: " . $configUser['name'] . PHP_EOL;
-			echo "Try adding 'sudo -u " . $configUser['name'] . " ' to the beginning of the command (without the single quotes)" . PHP_EOL;  
-			exit(0);
-		}
+	set_exception_handler('exceptionHandler');
+
+	if (!function_exists('posix_getuid')) {
+		echo "The posix extensions are required - see http://php.net/manual/en/book.posix.php" . PHP_EOL;
+		exit(0);
+	}
+	$user = posix_getpwuid(posix_getuid());
+	$configUser = posix_getpwuid(fileowner(OC::$configDir . 'config.php'));
+	if ($user['name'] !== $configUser['name']) {
+		echo "Console has to be executed with the user that owns the file config/config.php" . PHP_EOL;
+		echo "Current user: " . $user['name'] . PHP_EOL;
+		echo "Owner of config.php: " . $configUser['name'] . PHP_EOL;
+		echo "Try adding 'sudo -u " . $configUser['name'] . " ' to the beginning of the command (without the single quotes)" . PHP_EOL;  
+		exit(0);
 	}
 
 	$oldWorkingDir = getcwd();
 	if ($oldWorkingDir === false) {
-		echo "This script can be run from the Nextcloud root directory only." . PHP_EOL;
+		echo "This script can be run from the ownCloud root directory only." . PHP_EOL;
 		echo "Can't determine current working dir - the script will continue to work but be aware of the above fact." . PHP_EOL;
 	} else if ($oldWorkingDir !== __DIR__ && !chdir(__DIR__)) {
-		echo "This script can be run from the Nextcloud root directory only." . PHP_EOL;
-		echo "Can't change to Nextcloud root directory." . PHP_EOL;
+		echo "This script can be run from the ownCloud root directory only." . PHP_EOL;
+		echo "Can't change to ownCloud root directory." . PHP_EOL;
 		exit(1);
 	}
 
@@ -87,7 +97,7 @@ try {
 	$application->loadCommands(new ArgvInput(), new ConsoleOutput());
 	$application->run();
 } catch (Exception $ex) {
-	echo "An unhandled exception has been thrown:" . PHP_EOL;
-	echo $ex;
-	exit(1);
+	exceptionHandler($ex);
+} catch (Error $ex) {
+	exceptionHandler($ex);
 }
