@@ -1,23 +1,6 @@
 OC.L10N.register(
     "core",
     {
-    "Couldn't send mail to following users: %s " : "Неможливо надіслати листа наступним користувачам: %s ",
-    "Preparing update" : "Підготовка до оновлення",
-    "Turned on maintenance mode" : "Увімкнено режим технічного обслуговування",
-    "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
-    "Maintenance mode is kept active" : "Режим обслуговування залишається активним",
-    "Updating database schema" : "Оновлення схеми бази даних",
-    "Updated database" : "Базу даних оновлено",
-    "Checked database schema update" : "Перевірено оновлення схеми бази даних",
-    "Checking updates of apps" : "Перевірка оновлень додатків",
-    "Checked database schema update for apps" : "Перевірено оновлення схеми бази даних для додатків",
-    "Updated \"%s\" to %s" : "Оновлено \"%s\" до %s",
-    "Repair warning: " : "Попередження відновлення:",
-    "Repair error: " : "Помилка відновлення:",
-    "Starting code integrity check" : "Початок перевірки цілісності коду",
-    "Finished code integrity check" : "Завершено перевірку цілісності коду",
-    "Following apps have been disabled: %s" : "Наступні додатки були вимкнені: %s",
-    "Already up to date" : "Актуально",
     "Please select a file." : "Будь ласка, оберіть файл.",
     "File is too big" : "Файл занадто великий",
     "Invalid file provided" : "Надано невірний файл",
@@ -32,8 +15,224 @@ OC.L10N.register(
     "Couldn't reset password because the token is invalid" : "Неможливо скинути пароль, бо маркер є недійсним",
     "Couldn't reset password because the token is expired" : "Неможливо скинути пароль, бо маркер застарів",
     "Couldn't send reset email. Please make sure your username is correct." : "Не вдалося відправити скидання паролю. Будь ласка, переконайтеся, що ваше ім'я користувача є правильним.",
+    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Не вдалося відправити скидання паролю, тому що немає адреси електронної пошти для цього користувача. Будь ласка, зверніться до адміністратора.",
     "%s password reset" : "%s скидання паролю",
     "Couldn't send reset email. Please contact your administrator." : "Не можу надіслати email для скидання. Будь ласка, зверніться до вашого адміністратора.",
+    "Preparing update" : "Підготовка до оновлення",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Попередження відновлення:",
+    "Repair error: " : "Помилка відновлення:",
+    "Please use the command line updater because automatic updating is disabled in the config.php." : "Просимо запустити процес оновлення з командного рядка, оскільки автоматичне оновлення вимкнено у файлі config.php.",
+    "[%d / %d]: Checking table %s" : "[%d / %d]: Перевірка таблиці %s",
+    "Turned on maintenance mode" : "Увімкнено режим технічного обслуговування",
+    "Turned off maintenance mode" : "Вимкнено режим технічного обслуговування",
+    "Maintenance mode is kept active" : "Режим обслуговування залишається активним",
+    "Updating database schema" : "Оновлення схеми бази даних",
+    "Updated database" : "Базу даних оновлено",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Перевіряю, чи схема бази даних може бути оновлена (це може зайняти багато часу, залежно від розмірів бази даних)",
+    "Checked database schema update" : "Перевірено оновлення схеми бази даних",
+    "Checking updates of apps" : "Перевірка оновлень додатків",
+    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Перевіряю, чи схема бази даних для %s може бути оновлена (це може зайняти багато часу, залежно від розмірів бази даних)",
+    "Checked database schema update for apps" : "Перевірено оновлення схеми бази даних для додатків",
+    "Updated \"%s\" to %s" : "Оновлено \"%s\" до %s",
+    "Set log level to debug" : "Встановити рівень детальності журналу як налагодження",
+    "Reset log level" : "Скинути налаштування детальності журналу",
+    "Starting code integrity check" : "Початок перевірки цілісності коду",
+    "Finished code integrity check" : "Завершено перевірку цілісності коду",
+    "%s (3rdparty)" : "%s (стороннє)",
+    "%s (incompatible)" : "%s (несумісне)",
+    "Following apps have been disabled: %s" : "Наступні додатки були вимкнені: %s",
+    "Already up to date" : "Вже актуально",
+    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Були проблеми з перевіркою цілісності коду. Більше інформації…</a>",
+    "Settings" : "Налаштування",
+    "Problem loading page, reloading in 5 seconds" : "Проблема під час завантаження сторінки, повторне завантаження за 5 сек.",
+    "Saving..." : "Збереження...",
+    "Dismiss" : "Припинити",
+    "Password" : "Пароль",
+    "Cancel" : "Скасувати",
+    "seconds ago" : "секунди тому",
+    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Посилання для скидання вашого паролю було надіслано на ваш email. Якщо ви не отримали його найближчим часом, перевірте теку зі спамом.<br>Якщо і там немає, спитайте вашого місцевого адміністратора.",
+    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваші файли зашифровані. Якщо ви не зробили ключ відновлення, після скидання паролю відновити ваші дані буде неможливо.<br /> Якщо ви не знаєте, що робити, будь ласка, зверніться до адміністратора перед продовженням.<br /> Ви дійсно хочете продовжити?",
+    "I know what I'm doing" : "Я знаю що роблю",
+    "Password can not be changed. Please contact your administrator." : "Пароль не може бути змінено. Будь ласка, зверніться до вашого адміністратора",
+    "No" : "Ні",
+    "Yes" : "Так",
+    "Choose" : "Обрати",
+    "Error loading file picker template: {error}" : "Помилка при завантаженні шаблону вибору: {error}",
+    "Ok" : "Гаразд",
+    "Error loading message template: {error}" : "Помилка при завантаженні шаблону повідомлення: {error}",
+    "read-only" : "Тільки для читання",
+    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файловий конфлікт","{count} файлових конфліктів","{count} файлових конфліктів"],
+    "One file conflict" : "Один файловий конфлікт",
+    "New Files" : "Нових Файлів",
+    "Already existing files" : "Файли що вже існують",
+    "Which files do you want to keep?" : "Які файли ви хочете залишити?",
+    "If you select both versions, the copied file will have a number added to its name." : "При виборі обох версій, до назви копійованого файлу буде додана цифра",
+    "Continue" : "Продовжити",
+    "(all selected)" : "(все обрано)",
+    "({count} selected)" : "({count} обраних)",
+    "Error loading file exists template" : "Помилка при завантаженні шаблону існуючого файлу",
+    "Very weak password" : "Дуже слабкий пароль",
+    "Weak password" : "Слабкий пароль",
+    "So-so password" : "Такий собі пароль",
+    "Good password" : "Добрий пароль",
+    "Strong password" : "Надійний пароль",
+    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш веб-сервер ще не налаштований належним чином, щоб дозволити синхронізацію файлів, тому що інтерфейс WebDAV, здається, зіпсований.",
+    "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
+    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш каталог даних і ваші файли можливо доступні з інтернету. .htaccess файл не працює. Ми наполегливо рекомендуємо вам налаштувати ваш веб сервер таким чином, щоб каталог даних більше не був доступний або перемістіть каталог даних за межі кореня веб сервера.",
+    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP заголовок \"{header}\" не налаштований як \"{expected}\". Це потенційний ризик для безпеки чи приватності і ми радимо виправити це налаштування.",
+    "Shared" : "Опубліковано",
+    "Shared with {recipients}" : "Опубліковано для {recipients}",
+    "Error" : "Помилка",
+    "Error while sharing" : "Помилка під час публікації",
+    "Error while unsharing" : "Помилка під час відміни публікації",
+    "Error setting expiration date" : "Помилка при встановленні терміну дії",
+    "The public link will expire no later than {days} days after it is created" : "Доступ до опублікованого посилання буде припинено не пізніше ніж через {days} днів з моменту створення",
+    "Set expiration date" : "Встановити термін дії",
+    "Expiration" : "Закінчення",
+    "Expiration date" : "Термін дії",
+    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
+    "Resharing is not allowed" : "Пере-публікація не дозволяється",
+    "Share link" : "Поділитись посиланням",
+    "Link" : "Посилання",
+    "Password protect" : "Захистити паролем",
+    "Email link to person" : "Надіслати посилання електронною поштою",
+    "Send" : "Надіслати",
+    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
+    "Shared with you by {owner}" : "{owner} опублікував для Вас",
+    "group" : "група",
+    "remote" : "Віддалений",
+    "Unshare" : "Закрити доступ",
+    "can edit" : "може редагувати",
+    "access control" : "контроль доступу",
+    "Could not unshare" : "Неможливо припинити ділитися файлом",
+    "No users or groups found for {search}" : "Не знайдено груп або користувачів за пошуком {search}",
+    "No users found for {search}" : "Не знайдено жодного користувача для {search}",
+    "An error occurred. Please try again" : "Сталася помилка. Спробуйте ще раз",
+    "{sharee} (group)" : "{sharee} (група)",
+    "{sharee} (remote)" : "{sharee} (віддалений)",
+    "Share" : "Поділитися",
+    "Error removing share" : "Помилка під час вилучення спільного",
+    "Non-existing tag #{tag}" : "Ця позначка відсутня #{tag}",
+    "restricted" : "обмежено",
+    "invisible" : "невидимо",
+    "({scope})" : "({scope})",
+    "Delete" : "Видалити",
+    "Rename" : "Перейменувати",
+    "Collaborative tags" : "Позначки для співпраці",
+    "The object type is not specified." : "Не визначено тип об'єкту.",
+    "Enter new" : "Введіть новий",
+    "Add" : "Додати",
+    "Edit tags" : "Редагувати мітки",
+    "Error loading dialog template: {error}" : "Помилка при завантаженні шаблону діалогу: {error}",
+    "No tags selected for deletion." : "Жодних міток не обрано для видалення.",
+    "unknown text" : "невідомий текст",
+    "Hello world!" : "Привіт світ!",
+    "sunny" : "сонячно",
+    "Hello {name}, the weather is {weather}" : "Привіт {name}, погода {weather} ",
+    "Hello {name}" : "Привіт {name}",
+    "new" : "новий",
+    "_download %n file_::_download %n files_" : ["завантаження %n файлу","завантаження %n файлів","завантаження %n файлів"],
+    "An error occurred." : "Виникла помилка.",
+    "Please reload the page." : "Будь ласка, перезавантажте сторінку.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Оновлення не вдалося. За інформацією <a href=\"{url}\">зверніться до повідомлення на форумі</a>, що описує цю проблему.",
+    "Searching other places" : "Йде пошук в інших місцях",
+    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} результат пошуку в інших теках","{count} результатів пошуку в інших теках","{count} результатів пошуку в інших теках"],
+    "Personal" : "Особисте",
+    "Users" : "Користувачі",
+    "Apps" : "Додатки",
+    "Admin" : "Адмін",
+    "Help" : "Допомога",
+    "Access forbidden" : "Доступ заборонено",
+    "File not found" : "Файл не знайдено",
+    "The specified document has not been found on the server." : "Не вдалось знайти вказаний документ на сервері.",
+    "You can click here to return to %s." : "Ви можете натиснути тут для повернення до %s.",
+    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Агов,\n\nпросто повідомляємо вам, що %s поділився %s з вами.\nПерегляньте: %s\n\n",
+    "The share will expire on %s." : "Спільний доступ закінчиться %s.",
+    "Cheers!" : "Будьмо!",
+    "Internal Server Error" : "Внутрішня помилка серверу",
+    "The server encountered an internal error and was unable to complete your request." : "На сервері сталася внутрішня помилка, тому він не зміг виконати ваш запит.",
+    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Будь ласка, зверніться до адміністратора сервера, якщо ця помилка з'являється кілька разів, будь ласка, вкажіть технічні подробиці у вашому звіті.",
+    "More details can be found in the server log." : "Більше деталей може бути в журналі серверу.",
+    "Technical details" : "Технічні деталі",
+    "Remote Address: %s" : "Віддалена Адреса: %s",
+    "Request ID: %s" : "ID запиту: %s",
+    "Type: %s" : "Тип: %s",
+    "Code: %s" : "Код: %s",
+    "Message: %s" : "Повідомлення: %s",
+    "File: %s" : "Файл: %s",
+    "Line: %s" : "Рядок: %s",
+    "Trace" : "Трасування",
+    "Security warning" : "Попередження безпеки",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог даних і ваші файли можливо доступні з інтернету, тому що  .htaccess файл не працює.",
+    "Create an <strong>admin account</strong>" : "Створити <strong>обліковий запис адміністратора</strong>",
+    "Username" : "Ім'я користувача",
+    "Storage & database" : "Сховище і база даних",
+    "Data folder" : "Каталог даних",
+    "Configure the database" : "Налаштування бази даних",
+    "Only %s is available." : "Доступно тільки %s.",
+    "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP для того, щоб обрати тип БД.",
+    "For more details check out the documentation." : "За подробицями зверніться до документації.",
+    "Database user" : "Користувач бази даних",
+    "Database password" : "Пароль для бази даних",
+    "Database name" : "Назва бази даних",
+    "Database tablespace" : "Таблиця бази даних",
+    "Database host" : "Хост бази даних",
+    "Performance warning" : "Попередження продуктивності",
+    "SQLite will be used as database." : "В якості бази даних буде використана SQLite.",
+    "For larger installations we recommend to choose a different database backend." : "Для великих установок ми радимо вибрати іншу базу даних.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Використання SQLite особливо не рекомендується при синхронізації файлів з використанням клієнта для ПК.",
+    "Finish setup" : "Завершити встановлення",
+    "Finishing …" : "Завершується ...",
+    "Need help?" : "Потрібна допомога?",
+    "See the documentation" : "Дивіться документацію",
+    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ця програма вимагає увімкнений JavaScript для коректної роботи. Будь ласка, {linkstart} Увімкніть JavaScript {linkend}  та перезавантажте сторінку.",
+    "Log out" : "Вихід",
+    "Search" : "Пошук",
+    "Server side authentication failed!" : "Невдала аутентифікація з сервером!",
+    "Please contact your administrator." : "Будь ласка, зверніться до вашого Адміністратора.",
+    "An internal error occurred." : "Виникла внутрішня помилка.",
+    "Please try again or contact your administrator." : "Будь ласка, спробуйте ще раз або зверніться до адміністратора.",
+    "Username or email" : "Ім’я користувача або електронна пошта",
+    "Wrong password. Reset it?" : "Невірний пароль. Скинути його?",
+    "Wrong password." : "Невірний пароль.",
+    "Log in" : "Увійти",
+    "Stay logged in" : "Залишатись в системі",
+    "Alternative Logins" : "Альтернативні імена користувача",
+    "Use the following link to reset your password: {link}" : "Використовуйте наступне посилання для скидання пароля: {link}",
+    "New password" : "Новий пароль",
+    "New Password" : "Новий пароль",
+    "Reset password" : "Скинути пароль",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Агов,<br><br>просто повідомляємо вам, що %s поділився »%s« з вами.<br><a href=\"%s\">Перегляньте!</a><br><br>",
+    "This Nextcloud instance is currently in single user mode." : "Сервер Nextcloud в даний час працює в однокористувацькому режимі.",
+    "This means only administrators can use the instance." : "Це означає, що тільки адміністратори можуть використовувати сервер.",
+    "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора якщо це повідомлення не зникає або з'являється несподівано.",
+    "Thank you for your patience." : "Дякуємо за ваше терпіння.",
+    "You are accessing the server from an untrusted domain." : "Ви намагаєтеся отримати доступ до сервера з непідтвердженого домену.",
+    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Залежно від конфігурації Ви як адміністратор можете додати цей домен у список довірених, використовуйте кнопку нижче.",
+    "Add \"%s\" as trusted domain" : "Додати \"%s\" як довірений домен",
+    "App update required" : "Додаток потребує оновлення",
+    "%s will be updated to version %s" : "%s буде оновлено до версії %s",
+    "These apps will be updated:" : "Ці додатки будуть оновлені:",
+    "These incompatible apps will be disabled:" : "Ці несумісні додатки будуть вимкнені:",
+    "The theme %s has been disabled." : "Тему %s було вимкнено.",
+    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продовженням переконайтеся, що ви зробили резервну копію бази даних, каталогу конфігурації та каталогу з даними.",
+    "Start update" : "Почати оновлення",
+    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Щоб уникнути затримок у великих встановленнях, ви можете виконати наступну команду в каталозі встановлення:",
+    "Detailed logs" : "Деталізований журнал",
+    "Update needed" : "Оновлення необхідно",
+    "Please use the command line updater because you have a big instance." : "Просимо запустити процес оновлення з командного рядка, оскільки ви маєте багато даних.",
+    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "За допомогою зверніться до <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">документації</a>.",
+    "This %s instance is currently in maintenance mode, which may take a while." : "Цей %s знаходиться в режимі технічного обслуговування, яке може зайняти деякий час.",
+    "This page will refresh itself when the %s instance is available again." : "Ця сторінка автоматично перезавантажиться коли екземпляр %s стане знову доступний.",
+    "Error loading tags" : "Помилка завантаження міток",
+    "Tag already exists" : "Мітка вже існує",
+    "Error deleting tag(s)" : "Помилка видалення мітки(ок)",
+    "Error tagging" : "Помилка встановлення міток",
+    "Error untagging" : "Помилка зняття мітки",
+    "Error favoriting" : "Помилка додавання в улюблені",
+    "Error unfavoriting" : "Помилка видалення з улюбленого",
+    "Couldn't send mail to following users: %s " : "Неможливо надіслати листа наступним користувачам: %s ",
     "Sunday" : "Неділя",
     "Monday" : "Понеділок",
     "Tuesday" : "Вівторок",
@@ -79,198 +278,25 @@ OC.L10N.register(
     "Oct." : "Жов.",
     "Nov." : "Лис.",
     "Dec." : "Гру.",
-    "Settings" : "Налаштування",
-    "Saving..." : "Збереження...",
-    "Dismiss" : "Припинити",
-    "seconds ago" : "секунди тому",
-    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Посилання для скидання вашого паролю було надіслано на ваш email. Якщо ви не отримали його найближчим часом, перевірте теку зі спамом.<br>Якщо і там немає, спитайте вашого місцевого адміністратора.",
-    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Ваші файли зашифровані. Якщо ви не зробили ключ відновлення, після скидання паролю відновити ваші дані буде неможливо.<br /> Якщо ви не знаєте, що робити, будь ласка, зверніться до адміністратора перед продовженням.<br /> Ви дійсно хочете продовжити?",
-    "I know what I'm doing" : "Я знаю що роблю",
-    "Password can not be changed. Please contact your administrator." : "Пароль не може бути змінено. Будь ласка, зверніться до вашого адміністратора",
-    "No" : "Ні",
-    "Yes" : "Так",
-    "Choose" : "Обрати",
-    "Error loading file picker template: {error}" : "Помилка при завантаженні шаблону вибору: {error}",
-    "Ok" : "Гаразд",
-    "Error loading message template: {error}" : "Помилка при завантаженні шаблону повідомлення: {error}",
-    "read-only" : "Тільки для читання",
-    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файловий конфлікт","{count} файлових конфліктів","{count} файлових конфліктів"],
-    "One file conflict" : "Один файловий конфлікт",
-    "New Files" : "Нових Файлів",
-    "Already existing files" : "Файли що вже існують",
-    "Which files do you want to keep?" : "Які файли ви хочете залишити?",
-    "If you select both versions, the copied file will have a number added to its name." : "При виборі обох версій, до назви копійованого файлу буде додана цифра",
-    "Cancel" : "Скасувати",
-    "Continue" : "Продовжити",
-    "(all selected)" : "(все обрано)",
-    "({count} selected)" : "({count} обраних)",
-    "Error loading file exists template" : "Помилка при завантаженні шаблону існуючого файлу",
-    "Very weak password" : "Дуже слабкий пароль",
-    "Weak password" : "Слабкий пароль",
-    "So-so password" : "Такий собі пароль",
-    "Good password" : "Добрий пароль",
-    "Strong password" : "Надійний пароль",
-    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ваш веб-сервер ще не налаштований належним чином, щоб дозволити синхронізацію файлів, тому що інтерфейс WebDAV, здається, зіпсований.",
-    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Цей сервер не має підключення до Інтернету. Це означає, що деякі з функцій, таких як зовнішнє сховище, повідомлення про оновлення та встановлення сторонніх додатків не будуть працювати. Доступ до файлів віддалено і надсилання повідомлень поштою можуть не працювати. Ми пропонуємо включити підключення до Інтернету для цього сервера, якщо ви хочете, щоб всі функції працювали.",
-    "Error occurred while checking server setup" : "При перевірці налаштувань серверу сталася помилка",
-    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ваш каталог даних і ваші файли можливо доступні з інтернету. .htaccess файл не працює. Ми наполегливо рекомендуємо вам налаштувати ваш веб сервер таким чином, щоб каталог даних більше не був доступний або перемістіть каталог даних за межі кореня веб сервера.",
-    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "HTTP заголовок \"{header}\" не налаштований як \"{expected}\". Це потенційний ризик для безпеки чи приватності і ми радимо виправити це налаштування.",
-    "Shared" : "Опубліковано",
-    "Shared with {recipients}" : "Опубліковано для {recipients}",
-    "Error" : "Помилка",
-    "Error while sharing" : "Помилка під час публікації",
-    "Error while unsharing" : "Помилка під час відміни публікації",
-    "Error setting expiration date" : "Помилка при встановленні терміну дії",
-    "The public link will expire no later than {days} days after it is created" : "Доступ до опублікованого посилання буде припинено не пізніше ніж через {days} днів з моменту створення",
-    "Set expiration date" : "Встановити термін дії",
-    "Expiration" : "Закінчення",
-    "Expiration date" : "Термін дії",
-    "Choose a password for the public link" : "Вкажіть пароль для публічного посилання",
+    "Allow editing" : "Дозволити редагування",
     "Sending ..." : "Надсилання...",
     "Email sent" : "Лист надіслано",
-    "Resharing is not allowed" : "Пере-публікація не дозволяється",
-    "Share link" : "Поділитись посиланням",
-    "Link" : "Посилання",
-    "Password protect" : "Захистити паролем",
-    "Password" : "Пароль",
-    "Allow editing" : "Дозволити редагування",
-    "Email link to person" : "Надіслати посилання електронною поштою",
-    "Send" : "Надіслати",
-    "Shared with you and the group {group} by {owner}" : " {owner} опублікував для Вас та для групи {group}",
-    "Shared with you by {owner}" : "{owner} опублікував для Вас",
-    "group" : "група",
-    "remote" : "Віддалений",
+    "Send link via email" : "Надіслати посилання електронною поштою",
     "notify by email" : "повідомити по Email",
-    "Unshare" : "Закрити доступ",
     "can share" : "може ділитися з іншими",
-    "can edit" : "може редагувати",
     "create" : "створити",
     "change" : "змінити",
     "delete" : "видалити",
-    "access control" : "контроль доступу",
-    "No users or groups found for {search}" : "Не знайдено груп або користувачів за пошуком {search}",
-    "An error occured. Please try again" : "Виникла помилка. Будь ласка, спробуйте ще раз",
-    "{sharee} (group)" : "{sharee} (група)",
-    "Share" : "Поділитися",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поширити серед людей інших ownCloud'ів, використовуючи синтаксис ім'я_користувача@файли.укр/owncloud",
-    "Share with users or groups …" : "Поширити серед користувачів або груп ...",
-    "Share with users, groups or remote users …" : "Поширити серед локальних чи віддалених користувачів або груп ...",
+    "{sharee} (at {server})" : "{sharee} (на {server})",
+    "Share with users…" : "Поділитись з користувачами...",
+    "Share with users, groups or remote users…" : "Поділитись з користувачами, групами або віддаленими користувачами...",
+    "Share with users or groups…" : "Поділитись з користувачами або групами...",
+    "Share with users or remote users…" : "Поділитись з користувачами системи або віддаленими користувачами...",
     "Warning" : "Попередження",
-    "Error while sending notification" : "Помилка при надсиланні повідомлення",
-    "({scope})" : "({scope})",
-    "Delete" : "Видалити",
-    "Rename" : "Перейменувати",
-    "The object type is not specified." : "Не визначено тип об'єкту.",
-    "Enter new" : "Введіть новий",
-    "Add" : "Додати",
-    "Edit tags" : "Редагувати мітки",
-    "Error loading dialog template: {error}" : "Помилка при завантаженні шаблону діалогу: {error}",
-    "No tags selected for deletion." : "Жодних міток не обрано для видалення.",
-    "unknown text" : "невідомий текст",
-    "Hello world!" : "Привіт світ!",
-    "sunny" : "сонячно",
-    "Hello {name}, the weather is {weather}" : "Привіт {name}, погода {weather} ",
-    "Hello {name}" : "Привіт {name}",
-    "_download %n file_::_download %n files_" : ["завантаження %n файлу","завантаження %n файлів","завантаження %n файлів"],
-    "Updating {productName} to version {version}, this may take a while." : "Оновлення {productName} до версії {version}, це може займати деякий час.",
-    "An error occurred." : "Виникла помилка.",
-    "Please reload the page." : "Будь ласка, перезавантажте сторінку.",
-    "The update was unsuccessful. " : "Оновлення завершилось невдачею.",
-    "The update was successful. There were warnings." : "Оновлення виконалось успішно, але були попередження.",
-    "The update was successful. Redirecting you to ownCloud now." : "Оновлення виконалось успішно. Перенаправляємо вас на  ownCloud.",
-    "Searching other places" : "Йде пошук в інших місцях",
+    "Error while sending notification" : "Помилка під час надсилання повідомлення",
     "No search results in other folders" : "В інших теках нічого не знайдено",
-    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} результат пошуку в інших теках","{count} результатів пошуку в інших теках","{count} результатів пошуку в інших теках"],
-    "Personal" : "Особисте",
-    "Users" : "Користувачі",
-    "Apps" : "Додатки",
-    "Admin" : "Адмін",
-    "Help" : "Допомога",
-    "Error loading tags" : "Помилка завантаження міток",
-    "Tag already exists" : "Мітка вже існує",
-    "Error deleting tag(s)" : "Помилка видалення мітки(ок)",
-    "Error tagging" : "Помилка встановлення міток",
-    "Error untagging" : "Помилка зняття мітки",
-    "Error favoriting" : "Помилка додавання в улюблені",
-    "Error unfavoriting" : "Помилка видалення з улюбленого",
-    "Access forbidden" : "Доступ заборонено",
-    "File not found" : "Файл не знайдено",
-    "The specified document has not been found on the server." : "Не вдалось знайти вказаний документ на сервері.",
-    "You can click here to return to %s." : "Ви можете натиснути тут для повернення до %s.",
-    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Агов,\n\nпросто повідомляємо вам, що %s поділився %s з вами.\nПерегляньте: %s\n\n",
-    "The share will expire on %s." : "Спільний доступ закінчиться %s.",
-    "Cheers!" : "Будьмо!",
-    "Internal Server Error" : "Внутрішня помилка серверу",
-    "The server encountered an internal error and was unable to complete your request." : "На сервері сталася внутрішня помилка, тому він не зміг виконати ваш запит.",
-    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Будь ласка, зверніться до адміністратора сервера, якщо ця помилка з'являється кілька разів, будь ласка, вкажіть технічні подробиці у вашому звіті.",
-    "More details can be found in the server log." : "Більше деталей може бути в журналі серверу.",
-    "Technical details" : "Технічні деталі",
-    "Remote Address: %s" : "Віддалена Адреса: %s",
-    "Request ID: %s" : "ID запиту: %s",
-    "Type: %s" : "Тип: %s",
-    "Code: %s" : "Код: %s",
-    "Message: %s" : "Повідомлення: %s",
-    "File: %s" : "Файл: %s",
-    "Line: %s" : "Рядок: %s",
-    "Trace" : "Трасування",
-    "Security warning" : "Попередження безпеки",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог даних і ваші файли можливо доступні з інтернету, тому що  .htaccess файл не працює.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Для отримання інформації, як правильно налаштувати сервер, див. <a href=\"%s\" target=\"_blank\">документацію</a>.",
-    "Create an <strong>admin account</strong>" : "Створити <strong>обліковий запис адміністратора</strong>",
-    "Username" : "Ім'я користувача",
-    "Storage & database" : "Сховище і база даних",
-    "Data folder" : "Каталог даних",
-    "Configure the database" : "Налаштування бази даних",
-    "Only %s is available." : "Доступно тільки %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP для того, щоб обрати тип БД.",
-    "For more details check out the documentation." : "За подробицями зверніться до документації.",
-    "Database user" : "Користувач бази даних",
-    "Database password" : "Пароль для бази даних",
-    "Database name" : "Назва бази даних",
-    "Database tablespace" : "Таблиця бази даних",
-    "Database host" : "Хост бази даних",
-    "Performance warning" : "Попередження продуктивності",
-    "SQLite will be used as database." : "В якості бази даних буде використана SQLite.",
-    "For larger installations we recommend to choose a different database backend." : "Для великих установок ми радимо вибрати іншу базу даних.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Використання SQLite особливо не рекомендується при синхронізації файлів з використанням клієнта для ПК.",
-    "Finish setup" : "Завершити встановлення",
-    "Finishing …" : "Завершується ...",
-    "Need help?" : "Потрібна допомога?",
-    "See the documentation" : "Дивіться документацію",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Агов,<br><br>просто повідомляємо вам, що %s поділився »%s« з вами.<br><a href=\"%s\">Перегляньте!</a><br><br>",
-    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ця програма вимагає увімкнений JavaScript для коректної роботи. Будь ласка, {linkstart} Увімкніть JavaScript {linkend}  та перезавантажте сторінку.",
-    "Log out" : "Вихід",
-    "Search" : "Пошук",
-    "Server side authentication failed!" : "Невдала аутентифікація з сервером!",
-    "Please contact your administrator." : "Будь ласка, зверніться до вашого Адміністратора.",
-    "An internal error occured." : "Виникла внутрішня помилка.",
-    "Please try again or contact your administrator." : "Будь ласка, спробуйте ще раз або зверніться до адміністратора.",
-    "Log in" : "Увійти",
-    "Wrong password. Reset it?" : "Невірний пароль. Скинути його?",
-    "Wrong password." : "Невірний пароль.",
-    "Alternative Logins" : "Альтернативні імена користувача",
-    "Use the following link to reset your password: {link}" : "Використовуйте наступне посилання для скидання пароля: {link}",
-    "New password" : "Новий пароль",
-    "New Password" : "Новий пароль",
-    "Reset password" : "Скинути пароль",
-    "This Nextcloud instance is currently in single user mode." : "Сервер Nextcloud в даний час працює в однокористувацькому режимі.",
-    "This means only administrators can use the instance." : "Це означає, що тільки адміністратори можуть використовувати сервер.",
-    "Contact your system administrator if this message persists or appeared unexpectedly." : "Зверніться до вашого системного адміністратора якщо це повідомлення не зникає або з'являється несподівано.",
-    "Thank you for your patience." : "Дякуємо за ваше терпіння.",
-    "You are accessing the server from an untrusted domain." : "Ви намагаєтеся отримати доступ до сервера з непідтвердженого домену.",
-    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Залежно від конфігурації Ви як адміністратор можете додати цей домен у список довірених, використовуйте кнопку нижче.",
-    "Add \"%s\" as trusted domain" : "Додати \"%s\" як довірений домен",
-    "App update required" : "Додаток потребує оновлення",
-    "%s will be updated to version %s" : "%s буде оновлено до версії %s",
-    "These apps will be updated:" : "Ці додатки будуть оновлені:",
-    "These incompatible apps will be disabled:" : "Ці несумісні додатки будуть вимкнені:",
-    "The theme %s has been disabled." : "Тему %s було вимкнено.",
-    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продовженням переконайтеся, що ви зробили резервну копію бази даних, каталогу конфігурації та каталогу з даними.",
-    "Start update" : "Почати оновлення",
-    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Щоб уникнути затримок у великих встановленнях, ви можете виконати наступну команду в каталозі встановлення:",
-    "This %s instance is currently in maintenance mode, which may take a while." : "Цей %s знаходиться в режимі технічного обслуговування, яке може зайняти деякий час.",
-    "This page will refresh itself when the %s instance is available again." : "Ця сторінка автоматично перезавантажиться коли екземпляр %s стане знову доступний.",
-    "Error loading file picker template: {error}" : "Помилка при завантаженні шаблону вибору: {error}",
-    "Password can not be changed. Please contact your administrator." : "Пароль не може бути змінено. Будь ласка, зверніться до вашого адміністратора"
+    "Two-step verification" : "Дворівнева перевірка",
+    "An error occured while verifying the token" : "При верифікації токена виникла помилка",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Поширити серед людей інших ownCloud'ів, використовуючи синтаксис ім'я_користувача@файли.укр/owncloud"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
