@@ -5,28 +5,27 @@ OC.L10N.register(
     "This can usually be fixed by giving the webserver write access to the config directory" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\"",
     "See %s" : "Voir %s",
     "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ce problème est généralement résolu %sen donnant au serveur web un accès en écriture au répertoire de configuration%s.",
+    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %$1s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
     "Sample configuration detected" : "Configuration d'exemple détectée",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Il a été détecté que la configuration donnée à titre d'exemple a été copiée. Cela peut rendre votre installation inopérante et n'est pas pris en charge. Veuillez lire la documentation avant d'effectuer des modifications dans config.php",
+    "%1$s and %2$s" : "%1$s et %2$s",
+    "%1$s, %2$s and %3$s" : "%1$s, %2$s et %3$s",
+    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s et %4$s",
+    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s et %5$s",
     "PHP %s or higher is required." : "PHP %s ou supérieur est requis.",
     "PHP with a version lower than %s is required." : "PHP avec une version antérieure à %s est requis.",
+    "%sbit or higher PHP required." : "%sbit ou PHP supérieur est requis.",
     "Following databases are supported: %s" : "Les bases de données suivantes sont supportées : %s",
     "The command line tool %s could not be found" : "La commande %s est introuvable",
     "The library %s is not available." : "La librairie %s n'est pas disponible.",
     "Library %s with a version higher than %s is required - available version %s." : "La librairie %s doit être au moins à la version %s. Version disponible : %s.",
     "Library %s with a version lower than %s is required - available version %s." : "La librairie %s doit avoir une version antérieure à %s. Version disponible : %s.",
     "Following platforms are supported: %s" : "Les plateformes suivantes sont prises en charge : %s",
-    "Nextcloud %s or higher is required." : "Nextcloud %s ou supérieur est requis.",
-    "Nextcloud %s or lower is required." : "Nextcloud %s ou inférieur est requis.",
-    "Help" : "Aide",
-    "Personal" : "Personnel",
-    "Users" : "Utilisateurs",
-    "Admin" : "Administration",
-    "Recommended" : "Recommandée",
-    "App \"%s\" cannot be installed because it is not compatible with this version of Nextcloud." : "L'application \"%s\" ne peut pas être installée car elle n'est pas compatible avec cette version de Nextcloud.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
-    "No app name specified" : "Aucun nom d'application spécifié",
+    "Server version %s or higher is required." : "Un serveur de version %s ou supérieure est requis.",
+    "Server version %s or lower is required." : "Un serveur de version %s ou inférieure est requis.",
     "Unknown filetype" : "Type de fichier inconnu",
     "Invalid image" : "Image non valable",
+    "Avatar image is not square" : "L'image d'avatar n'est pas carré",
     "today" : "aujourd'hui",
     "yesterday" : "hier",
     "_%n day ago_::_%n days ago_" : ["il y a %n jour","il y a %n jours"],
@@ -37,34 +36,20 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["Il y a %n heure","Il y a %n heures"],
     "_%n minute ago_::_%n minutes ago_" : ["il y a %n minute","il y a %n minutes"],
     "seconds ago" : "il y a quelques secondes",
-    "web services under your control" : "services web sous votre contrôle",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Le module avec l'id: %s n'existe pas. Merci de l'activer dans les paramètres d'applications ou de contacter votre administrateur.",
-    "Empty filename is not allowed" : "Le nom de fichier ne peut pas être vide",
-    "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
-    "4-byte characters are not supported in file names" : "Les caractères sur 4 octets ne sont pas pris en charge dans les noms de fichiers",
     "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
     "File name contains at least one invalid character" : "Le nom de fichier contient un (des) caractère(s) non valide(s)",
     "File name is too long" : "Nom de fichier trop long",
-    "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
-    "Can't read file" : "Impossible de lire le fichier",
-    "App directory already exists" : "Le dossier de l'application existe déjà",
-    "Can't create app folder. Please fix permissions. %s" : "Impossible de créer le dossier de l'application. Corrigez les droits d'accès. %s",
-    "Archive does not contain a directory named %s" : "Le fichier archive ne contient pas de répertoire %s",
-    "No source specified when installing app" : "Aucune source spécifiée pour installer l'application",
-    "No href specified when installing app from http" : "Aucun href spécifié pour installer l'application par http",
-    "No path specified when installing app from local file" : "Aucun chemin spécifié pour installer l'application depuis un fichier local",
-    "Archives of type %s are not supported" : "Les archives de type %s ne sont pas prises en charge",
-    "Failed to open archive when installing app" : "Échec de l'ouverture de l'archive lors de l'installation de l'application",
-    "App does not provide an info.xml file" : "L'application ne fournit pas de fichier info.xml",
-    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La signature n'a pas pu être vérifiée. Merci de contacter le développeur de l'application et de vérifier votre page d'administration.",
-    "App can't be installed because of not allowed code in the App" : "L'application ne peut être installée car elle contient du code non-autorisé",
-    "App can't be installed because it is not compatible with this version of Nextcloud" : "L'application ne peut être installée car elle n'est pas compatible avec cette version de Nextcloud",
-    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'application ne peut être installée car elle contient la balise <shipped>true</shipped> qui n'est pas autorisée pour les applications non incluses par défaut",
-    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "L'App ne peut pas être installé car la version dans info.xml diffère de la version signalée par l' app store",
-    "Application is not enabled" : "L'application n'est pas activée",
-    "Authentication error" : "Erreur d'authentification",
-    "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
-    "Unknown user" : "Utilisateur inconnu",
+    "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
+    "Empty filename is not allowed" : "Le nom de fichier ne peut pas être vide",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Server settings" : "Paramètres serveur",
+    "Sharing" : "Partage",
+    "Encryption" : "Chiffrement",
+    "Additional settings" : "Paramètres supplémentaires",
+    "Tips & tricks" : "Trucs et astuces",
+    "%s enter the database username and name." : "%s entrez le nom d'utilisateur et le nom de la base de données.",
     "%s enter the database username." : "%s entrez le nom d'utilisateur de la base de données.",
     "%s enter the database name." : "%s entrez le nom de la base de données.",
     "%s you may not use dots in the database name" : "%s vous ne pouvez pas utiliser de points dans le nom de la base de données",
@@ -114,32 +99,97 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Le partage de %s a échoué car le service %s n'a pas trouvé sa source..",
     "Sharing %s failed, because the file could not be found in the file cache" : "Le partage de %s a échoué car le fichier n'a pas été trouvé dans les fichiers mis en cache.",
     "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
+    "Files can't be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
+    "Files can't be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
     "Expiration date is in the past" : "La date d'expiration est dans le passé",
     "Cannot set expiration date more than %s days in the future" : "Impossible de définir la date d'expiration à plus de %s jours dans le futur",
     "Could not find category \"%s\"" : "Impossible de trouver la catégorie \"%s\"",
+    "Sunday" : "Dimanche",
+    "Monday" : "Lundi",
+    "Tuesday" : "Mardi",
+    "Wednesday" : "Mercredi",
+    "Thursday" : "Jeudi",
+    "Friday" : "Vendredi",
+    "Saturday" : "Samedi",
+    "Sun." : "Dim.",
+    "Mon." : "Lun.",
+    "Tue." : "Mar.",
+    "Wed." : "Mer.",
+    "Thu." : "Jeu.",
+    "Fri." : "Ven.",
+    "Sat." : "Sam.",
+    "Su" : "Di",
+    "Mo" : "Lu",
+    "Tu" : "Ma",
+    "We" : "Me",
+    "Th" : "Je",
+    "Fr" : "Ve",
+    "Sa" : "Sa",
+    "January" : "Janvier",
+    "February" : "Février",
+    "March" : "Mars",
+    "April" : "Avril",
+    "May" : "Mai",
+    "June" : "Juin",
+    "July" : "Juillet",
+    "August" : "Août",
+    "September" : "Septembre",
+    "October" : "Octobre",
+    "November" : "Novembre",
+    "December" : "Décembre",
+    "Jan." : "Jan.",
+    "Feb." : "Fév.",
+    "Mar." : "Mars",
+    "Apr." : "Avr.",
+    "May." : "Mai",
+    "Jun." : "Juin",
+    "Jul." : "Juil.",
+    "Aug." : "Août",
+    "Sep." : "Sep.",
+    "Oct." : "Oct.",
+    "Nov." : "Nov.",
+    "Dec." : "Déc.",
     "Apps" : "Applications",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", \"_@-\" et \".\" (le point)",
     "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
     "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
     "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
+    "Login canceled by app" : "L'authentification a été annulé par l'application",
+    "User disabled" : "Utilisateur désactivé",
+    "Help" : "Aide",
+    "Personal" : "Personnel",
+    "Users" : "Utilisateurs",
+    "Admin" : "Administration",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'application \"%s\" ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'application \"%s\" ne peut être installée car elle n'est pas compatible avec cette version du serveur",
+    "No app name specified" : "Aucun nom d'application spécifié",
+    "App '%s' could not be installed!" : "L'application \"%s\" ne peut pas être installée !",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "L'application \"%s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %s",
+    "a safe home for all your data" : "un endroit sûr pour toutes vos données",
+    "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
+    "Can't read file" : "Impossible de lire le fichier",
+    "Application is not enabled" : "L'application n'est pas activée",
+    "Authentication error" : "Erreur d'authentification",
+    "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
+    "Unknown user" : "Utilisateur inconnu",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Aucun pilote de base de données n’est installé (sqlite, mysql ou postgresql).",
-    "Microsoft Windows Platform is not supported" : "La plate-forme Microsoft Windows n'est pas prise en charge.",
-    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Executer un serveur Nextcloud sur une plate-forme Microsoft Windows n'est pas pris en charge. Si vous n'avez pas la possibilité de migrer votre serveur, nous vous suggérons d'utiliser un serveur Linux dans une machine virtuelle . Les paquets Linux nécessaires ainsi que des images virtuelles faciles à déployer se trouvent sur <a href=\"%s\">%s</a>. Pour migrer des installations existantes vers Linux, vous trouverez des conseils et des scripts de migration dans <a href=\"%s\">notre documentation</a>.",
     "Cannot write into \"config\" directory" : "Impossible d’écrire dans le répertoire \"config\"",
     "Cannot write into \"apps\" directory" : "Impossible d’écrire dans le répertoire \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ce problème est généralement résolu %sen donnant au serveur web un accès en écriture au répertoire apps%s ou en désactivant l'appstore dans le fichier de configuration.",
     "Cannot create \"data\" directory (%s)" : "Impossible de créer le répertoire \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ce problème est généralement résolu <a href=\"%s\" target=\"_blank\">en donnant au serveur web un accès en écriture au répertoire racine</a>.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Ce problème est généralement résolu <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">en donnant au serveur web un accès en écriture au répertoire racine</a>.",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Le problème de permissions peut généralement être résolu %sen donnant au serveur web un accès en écriture au répertoire racine%s",
     "Setting locale to %s failed" : "Echec de la spécification des paramètres régionaux à %s",
     "Please install one of these locales on your system and restart your webserver." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
     "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
     "PHP module %s not installed." : "Le module PHP %s n’est pas installé.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Le paramètre PHP \"%s\" n'est pas \"%s\".",
-    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajuster ce paramètre dans php.ini permettra à Nextcloud de fonctionner à nouveau",
+    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajuster ce paramètre dans php.ini fera fonctionner Nextcould à nouveau",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload est à \"%s\" alors que la valeur \"0\" est attendue",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pour corriger ce problème mettez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 au moins est requis. Actuellement %s est installé.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Pour régler ce problème, mettez à jour votre version de libxml2 et redémarrez votre serveur web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP semble configuré de manière à supprimer les blocs PHPdoc du code. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Les modules PHP ont été installés mais sont toujours indiqués comme manquants ?",
@@ -156,7 +206,36 @@ OC.L10N.register(
     "Storage unauthorized. %s" : "Espace de stockage non autorisé. %s",
     "Storage incomplete configuration. %s" : "Configuration de l'espace de stockage incomplète. %s",
     "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
+    "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
+    "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
+    "4-byte characters are not supported in file names" : "Les caractères sur 4 octets ne sont pas pris en charge dans les noms de fichiers",
+    "App directory already exists" : "Le dossier de l'application existe déjà",
+    "Can't create app folder. Please fix permissions. %s" : "Impossible de créer le dossier de l'application. Corrigez les droits d'accès. %s",
+    "Archive does not contain a directory named %s" : "Le fichier archive ne contient pas de répertoire %s",
+    "No source specified when installing app" : "Aucune source spécifiée pour installer l'application",
+    "No href specified when installing app from http" : "Aucun href spécifié pour installer l'application par http",
+    "No path specified when installing app from local file" : "Aucun chemin spécifié pour installer l'application depuis un fichier local",
+    "Archives of type %s are not supported" : "Les archives de type %s ne sont pas prises en charge",
+    "Failed to open archive when installing app" : "Échec de l'ouverture de l'archive lors de l'installation de l'application",
+    "App does not provide an info.xml file" : "L'application ne fournit pas de fichier info.xml",
+    "App cannot be installed because appinfo file cannot be read." : "L'application ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "La signature n'a pas pu être vérifiée. Merci de contacter le développeur de l'application et de vérifier votre page d'administration.",
+    "App can't be installed because of not allowed code in the App" : "L'application ne peut être installée car elle contient du code non-autorisé",
+    "App can't be installed because it is not compatible with this version of the server" : "L'application ne peut être installée car elle n'est pas compatible avec cette version du serveur",
+    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'application ne peut être installée car elle contient la balise <shipped>true</shipped> qui n'est pas autorisée pour les applications non incluses par défaut",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "L'App ne peut pas être installé car la version dans info.xml diffère de la version signalée par l' app store",
+    "Logging" : "Connexion",
+    "Recommended" : "Recommandée",
+    "Microsoft Windows Platform is not supported" : "La plate-forme Microsoft Windows n'est pas prise en charge.",
+    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself." : "L'exécution de Nextcloud Server sur une plateforme Microsoft Windows n'est pas supportée. Nous suggérons d'utilier un serveur Linux dans une machine virtuelle si vous n'avez pas la possibilité de migrer le serveur lui-même.",
     "Storage not available" : "Support de stockage non disponible",
-    "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s"
+    "ownCloud %s or higher is required." : "Nextcloud %s ou supérieur est requis.",
+    "ownCloud %s or lower is required." : "Nextcloud %s ou inférieur est requis.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of Nextcloud." : "L'application \"%s\" ne peut être installée car elle n'est pas compatible avec cette version de Nextcloud.",
+    "App can't be installed because it is not compatible with this version of Nextcloud" : "L'application ne peut être installée car elle n'est pas compatible avec cette version de Nextcloud",
+    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "L'application ne peut être installée car la version dans info.xml/version n'est pas la même que la version signalée sur l'app store",
+    "Hint: You can speed up the upgrade by executing this SQL command manually: ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;" : "Aide : Vous pouvez accélérer la mise à jour en exécutant manuellement la commande SQL suivante : ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;",
+    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Exécuter Nextcloud Server sur une plateforme Microsoft Windows n'est pas supporté. Nous vous suggérons d'utiliser un serveur Linux dans une machine virtuelle si vous n'avez pas l'option de migrer votre serveur. Trouver les paquets Linux aussi facilement que de déployer une image de machine virtuelle sur <a href=\"%s\">%s</a>. Pour migrer vos installations existantes sur Linux, vous pouvez trouver plein d'astuces et un script de migration sur  <a href=\"%s\">notre documentation</a>.",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Ce problème est généralement résolu en <a href=\"%s\" target=\"_blank\">donnant les accès en écriture dans le répertoire root</a>."
 },
 "nplurals=2; plural=(n > 1);");
