@@ -5,28 +5,27 @@ OC.L10N.register(
     "This can usually be fixed by giving the webserver write access to the config directory" : "多くの場合、これはWebサーバーにconfigディレクトリへの書き込み権限を与えることで解決できます。",
     "See %s" : "%s を閲覧",
     "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "多くの場合、これは %s Webサーバーにconfigディレクトリ %s への書き込み権限を与えることで解決できます。",
+    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "アプリ %1$s のファイルが正しく置き換えられませんでした。サーバーと互換性のあるバージョンであることを確認してください。",
     "Sample configuration detected" : "サンプル設定が見つかりました。",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "サンプル設定がコピーされてそのままです。このままではインストールが失敗し、サポート対象外になります。config.phpを変更する前にドキュメントを確認してください。",
+    "%1$s and %2$s" : "%1$s と %2$s",
+    "%1$s, %2$s and %3$s" : "%1$s と %2$s、%3$s",
+    "%1$s, %2$s, %3$s and %4$s" : "%1$s と %2$s、%3$s、%4$s",
+    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s と %2$s、%3$s、%4$s、%5$s",
     "PHP %s or higher is required." : "PHP %s 以上が必要です。",
     "PHP with a version lower than %s is required." : "%s 以前のバージョンのPHPが必要です。",
+    "%sbit or higher PHP required." : "%sbit 以上の新しいバージョンのPHPが必要です。",
     "Following databases are supported: %s" : "次のデータベースをサポートしています: %s",
     "The command line tool %s could not be found" : "コマンド '%s' は見つかりませんでした。",
     "The library %s is not available." : " %s ライブラリーが利用できません。",
     "Library %s with a version higher than %s is required - available version %s." : "%s ライブラリーは、%s よりも新しいバージョンが必要です。利用可能なバージョンは、 %s です。",
     "Library %s with a version lower than %s is required - available version %s." : "%s ライブラリーは、%s よりも古いバージョンが必要です。利用可能なバージョンは、 %s です。",
     "Following platforms are supported: %s" : "次のプラットフォームをサポートしています: %s",
-    "Nextcloud %s or higher is required." : "Nextcloud %s 以上が必要です。",
-    "Nextcloud %s or lower is required." : "Nextcloud %s 以下が必要です。",
-    "Help" : "ヘルプ",
-    "Personal" : "個人",
-    "Users" : "ユーザー",
-    "Admin" : "管理",
-    "Recommended" : "おすすめ",
-    "App \"%s\" cannot be installed because it is not compatible with this version of Nextcloud." : " \"%s\" アプリは、このバージョンのNextcloudと互換性がない為、インストールできません。",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "次の依存関係が満たされないため、\"%s\" アプリをインストールできません：%s",
-    "No app name specified" : "アプリ名が未指定",
+    "Server version %s or higher is required." : "サーバーの %s よりも高いバージョンが必要です。",
+    "Server version %s or lower is required." : "サーバーの %s よりも低いバージョンが必要です。",
     "Unknown filetype" : "不明なファイルタイプ",
     "Invalid image" : "無効な画像",
+    "Avatar image is not square" : "アバター画像が正方形ではありません",
     "today" : "今日",
     "yesterday" : "1日前",
     "_%n day ago_::_%n days ago_" : ["%n 日前"],
@@ -37,34 +36,20 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n 時間前"],
     "_%n minute ago_::_%n minutes ago_" : ["%n 分前"],
     "seconds ago" : "数秒前",
-    "web services under your control" : "あなたが管理するウェブサービス",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "id: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
-    "Empty filename is not allowed" : "空のファイル名は許可されていません",
-    "Dot files are not allowed" : "ドットファイルは許可されていません",
-    "4-byte characters are not supported in file names" : "ファイル名に4バイト文字を使用するのはサポートされていません",
     "File name is a reserved word" : "ファイル名が予約された単語です",
     "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
     "File name is too long" : "ファイル名が長すぎます",
-    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
-    "Can't read file" : "ファイルを読み込めません",
-    "App directory already exists" : "アプリディレクトリはすでに存在します",
-    "Can't create app folder. Please fix permissions. %s" : "アプリフォルダーを作成できませんでした。%s のパーミッションを修正してください。",
-    "Archive does not contain a directory named %s" : "%s という名前のディレクトリは、アーカイブに含まれていません",
-    "No source specified when installing app" : "アプリインストール時のソースが未指定",
-    "No href specified when installing app from http" : "アプリインストール時のhttpの URL が未指定",
-    "No path specified when installing app from local file" : "アプリインストール時のローカルファイルのパスが未指定",
-    "Archives of type %s are not supported" : "\"%s\"タイプのアーカイブ形式は未サポート",
-    "Failed to open archive when installing app" : "アプリをインストール中にアーカイブファイルを開けませんでした。",
-    "App does not provide an info.xml file" : "アプリにinfo.xmlファイルが入っていません",
-    "Signature could not get checked. Please contact the app developer and check your admin screen." : "署名が確認できませんでした｡このアプリの開発者へ連絡し、管理画面を確認してください。",
-    "App can't be installed because of not allowed code in the App" : "アプリで許可されないコードが入っているのが原因でアプリがインストールできません",
-    "App can't be installed because it is not compatible with this version of Nextcloud" : "アプリは、このバージョンのNextcloudと互換性がないためインストールできません。",
-    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "非shippedアプリには許可されない<shipped>true</shipped>タグが含まれているためにアプリをインストールできません。",
-    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "info.xmlのバージョンがアプリストアのバージョンと合っていないため、アプリはインストールされません",
-    "Application is not enabled" : "アプリケーションは無効です",
-    "Authentication error" : "認証エラー",
-    "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
-    "Unknown user" : "不明なユーザー",
+    "Dot files are not allowed" : "ドットファイルは許可されていません",
+    "Empty filename is not allowed" : "空のファイル名は許可されていません",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "Server settings" : "サーバー設定",
+    "Sharing" : "共有",
+    "Encryption" : "暗号化",
+    "Additional settings" : "追加設定",
+    "Tips & tricks" : "ヒントとコツ",
+    "%s enter the database username and name." : "%s データベース名とデータベースのユーザー名を入力してください。",
     "%s enter the database username." : "%s のデータベースのユーザー名を入力してください。",
     "%s enter the database name." : "%s のデータベース名を入力してください。",
     "%s you may not use dots in the database name" : "%s ではデータベース名にドットを利用できないかもしれません。",
@@ -80,7 +65,7 @@ OC.L10N.register(
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
     "Set an admin username." : "管理者のユーザー名を設定",
-    "Set an admin password." : "管理者のパスワードを設定。",
+    "Set an admin password." : "管理者のパスワードを設定",
     "Can't create or write into the data directory %s" : "%s データディレクトリに作成、書き込みができません",
     "Invalid Federated Cloud ID" : "無効な統合されたクラウドID",
     "%s shared »%s« with you" : "%sが あなたと »%s«を共有しました",
@@ -114,37 +99,102 @@ OC.L10N.register(
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "%s の共有に失敗しました。%s のバックエンド共有に必要なソースが見つかりませんでした。",
     "Sharing %s failed, because the file could not be found in the file cache" : "%s の共有に失敗しました。ファイルキャッシュにファイルがありませんでした。",
     "Cannot increase permissions of %s" : "%s　の権限を強化できません",
+    "Files can't be shared with delete permissions" : "削除権限つきでファイルを共有できません。",
+    "Files can't be shared with create permissions" : "作成権限つきでファイルを共有できません。",
     "Expiration date is in the past" : "有効期限が切れています",
     "Cannot set expiration date more than %s days in the future" : "有効期限を%s日以降に設定できません。",
     "Could not find category \"%s\"" : "カテゴリ \"%s\" が見つかりませんでした",
+    "Sunday" : "日曜日",
+    "Monday" : "月曜日",
+    "Tuesday" : "火曜日",
+    "Wednesday" : "水曜日",
+    "Thursday" : "木曜日",
+    "Friday" : "金曜日",
+    "Saturday" : "土曜日",
+    "Sun." : "日",
+    "Mon." : "月",
+    "Tue." : "火",
+    "Wed." : "水",
+    "Thu." : "木",
+    "Fri." : "金",
+    "Sat." : "土",
+    "Su" : "日",
+    "Mo" : "月",
+    "Tu" : "火",
+    "We" : "水",
+    "Th" : "木",
+    "Fr" : "金",
+    "Sa" : "土",
+    "January" : "1月",
+    "February" : "2月",
+    "March" : "3月",
+    "April" : "4月",
+    "May" : "5月",
+    "June" : "6月",
+    "July" : "7月",
+    "August" : "8月",
+    "September" : "9月",
+    "October" : "10月",
+    "November" : "11月",
+    "December" : "12月",
+    "Jan." : "1月",
+    "Feb." : "2月",
+    "Mar." : "3月",
+    "Apr." : "4月",
+    "May." : "5月",
+    "Jun." : "6月",
+    "Jul." : "7月",
+    "Aug." : "8月",
+    "Sep." : "9月",
+    "Oct." : "10月",
+    "Nov." : "11月",
+    "Dec." : "12月",
     "Apps" : "アプリ",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列は、次のものです： \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "ユーザー名で利用できる文字列は、次のものです： \"a-z\", \"A-Z\", \"0-9\", \"_.@-\"",
     "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
     "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
     "A valid password must be provided" : "有効なパスワードを指定する必要があります",
     "The username is already being used" : "ユーザー名はすでに使われています",
+    "Login canceled by app" : "アプリによりログインが中止されました",
+    "User disabled" : "ユーザーは無効です",
+    "Help" : "ヘルプ",
+    "Personal" : "個人",
+    "Users" : "ユーザー",
+    "Admin" : "管理",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリ名 \"%s\"  がインストールできません。",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "\"%s\" アプリは、このバージョンのサーバーと互換性がないためインストールされませんでした。",
+    "No app name specified" : "アプリ名が未指定",
+    "App '%s' could not be installed!" : "'%s' アプリをインストールできませんでした。",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "次の依存関係が満たされないため、\"%s\" アプリをインストールできません：%s",
+    "a safe home for all your data" : "あなたの全データの安全な家",
+    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
+    "Can't read file" : "ファイルを読み込めません",
+    "Application is not enabled" : "アプリケーションは無効です",
+    "Authentication error" : "認証エラー",
+    "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
+    "Unknown user" : "不明なユーザー",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "データベースドライバー (sqlite, mysql, postgresql) がインストールされていません。",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows サーバーはサポートしていません。",
-    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Microsoft Windowsサーバー上での Nextcloud の動作は、サポートされていません。現在のサーバーOSを変更することができないのであれば、仮想マシン上で Linuxサーバーを動かすことをお勧めします。仮想マシンイメージを配置するのと同じぐらい簡単にLinuxパッケージを<a href=\"%s\">%s</a>で見つけられます。現在稼働中の設定をLinuxに移行する 移行スクリプトと注意点をこちらの<a href=\"%s\">ドキュメント</a>で確認してください。",
     "Cannot write into \"config\" directory" : "\"config\" ディレクトリに書き込みができません",
     "Cannot write into \"apps\" directory" : "\"apps\" ディレクトリに書き込みができません",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "多くの場合、これは %s Webサーバーにappsディレクトリ %s への書き込み権限を与えるか、設定ファイルでアプリストアを無効化することで解決できます。",
     "Cannot create \"data\" directory (%s)" : "\"data\" ディレクトリ (%s) を作成できません",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "多くの場合、これは<a href=\"%s\" target=\"_blank\">Webサーバーにルートディレクトリへの書き込み権限を与える</a>ことで解決できます。",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "通常、<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">Webサーバーにルートディレクトリへの書き込み権限を与える</a>ことで解決できます。",
     "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "多くの場合、パーミッションは %s Webサーバーにルートディレクトリ %s への書き込み権限を与えることで解決できます。",
     "Setting locale to %s failed" : "ロケールを %s に設定できませんでした",
     "Please install one of these locales on your system and restart your webserver." : "これらのロケールのうちいずれかをシステムにインストールし、Webサーバーを再起動してください。",
     "Please ask your server administrator to install the module." : "サーバー管理者にモジュールのインストールを依頼してください。",
     "PHP module %s not installed." : "PHP のモジュール %s がインストールされていません。",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP設定の\"%s\"は \"%s\"に設定されていません",
-    "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini 中の設定を調整するとNextcloudはもう一度動作するでしょう。 ",
+    "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini のこの設定を調整して、再度 Nextcloudを起動してください。",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload の値は \"0\" であるべきですが、\"%s\" に設定されています",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "この問題を修正するには、php.ini ファイルの <code>mbstring.func_overload</code> を <code>0</code> に設定してください。",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 バージョン 2.7.0 が最低必要です。現在 %s がインストールされています。",
+    "To fix this issue update your libxml2 version and restart your web server." : "この問題を解決するには、libxml2 を更新して、ウェブサーバーを再起動してください。",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHPでインラインドキュメントブロックを取り除く設定になっています。これによりコアアプリで利用できないものがいくつかあります。",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "これは、Zend OPcacheやeAccelerator 等のキャッシュ/アクセラレーターが原因かもしれません。",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP モジュールはインストールされていますが、まだ一覧に表示されていますか？",
     "Please ask your server administrator to restart the web server." : "サーバー管理者にWebサーバーを再起動するよう依頼してください。",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 が必要です",
+    "PostgreSQL >= 9 required" : "PostgreSQL 9以上が必要です",
     "Please upgrade your database version" : "新しいバージョンのデータベースにアップグレードしてください",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "ディレクトリが他のユーザーから見えないように、パーミッションを 0770 に変更してください。",
     "Data directory (%s) is readable by other users" : "データディレクトリ (%s) は他のユーザーも閲覧することができます",
@@ -156,7 +206,36 @@ OC.L10N.register(
     "Storage unauthorized. %s" : "権限のないストレージです。 %s",
     "Storage incomplete configuration. %s" : "設定が未完了のストレージです。 %s",
     "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
+    "Storage is temporarily not available" : "ストレージは一時的に利用できません",
+    "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
+    "4-byte characters are not supported in file names" : "ファイル名に4バイト文字を使用するのはサポートされていません",
+    "App directory already exists" : "アプリディレクトリはすでに存在します",
+    "Can't create app folder. Please fix permissions. %s" : "アプリフォルダーを作成できませんでした。%s のパーミッションを修正してください。",
+    "Archive does not contain a directory named %s" : "%s という名前のディレクトリは、アーカイブに含まれていません",
+    "No source specified when installing app" : "アプリインストール時のソースが未指定",
+    "No href specified when installing app from http" : "アプリインストール時のhttpの URL が未指定",
+    "No path specified when installing app from local file" : "アプリインストール時のローカルファイルのパスが未指定",
+    "Archives of type %s are not supported" : "\"%s\"タイプのアーカイブ形式は未サポート",
+    "Failed to open archive when installing app" : "アプリをインストール中にアーカイブファイルを開けませんでした。",
+    "App does not provide an info.xml file" : "アプリにinfo.xmlファイルが入っていません",
+    "App cannot be installed because appinfo file cannot be read." : "appinfoファイルが読み込めないため、アプリがインストールできません。",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "署名が確認できませんでした｡このアプリの開発者へ連絡し、管理画面を確認してください。",
+    "App can't be installed because of not allowed code in the App" : "アプリで許可されないコードが入っているのが原因でアプリがインストールできません",
+    "App can't be installed because it is not compatible with this version of the server" : "アプリは、このバージョンのサーバーと互換性がないためインストールされませんでした。",
+    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "非shippedアプリには許可されない<shipped>true</shipped>タグが含まれているためにアプリをインストールできません。",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "info.xmlのバージョンがアプリストアのバージョンと合っていないため、アプリはインストールされません",
+    "Logging" : "ロギング",
+    "Recommended" : "おすすめ",
+    "Microsoft Windows Platform is not supported" : "Microsoft Windows プラットフォームはサポートしていません。",
+    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself." : "マイクロソフト Windowsプラットフォーム上での Nextcloudの動作をサポートしていません。サーバー丸ごと移行する方式をとれない場合は仮想マシンで Linux を動かすことをお勧めします。",
     "Storage not available" : "ストレージが利用できません",
-    "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s"
+    "ownCloud %s or higher is required." : "ownCloud %s 以上が必要です",
+    "ownCloud %s or lower is required." : "ownCloud %s 以下が必要です",
+    "App \"%s\" cannot be installed because it is not compatible with this version of Nextcloud." : "\"%s\" アプリはこのバージョンのNextcloudと互換性がないためインストールできません。",
+    "App can't be installed because it is not compatible with this version of Nextcloud" : "このバージョンのNextcloudと互換性がないため、アプリケーションをインストールできません",
+    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "info.xml/version のバージョンがアプリストアのバージョンと合っていないため、アプリはインストールされません",
+    "Hint: You can speed up the upgrade by executing this SQL command manually: ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;" : "ヒント：次のSQLコマンドを手動で実行すると、アップグレードを高速化できます： ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;",
+    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Microsoft WindowsプラットフォームでのNextcloud Serverの実行はサポートされていません。サーバー自体を移行するオプションがない場合は、仮想マシンでLinuxサーバーを使用することをお勧めします。 <a href=\"%s\"> %s </a>でLinuxパッケージを見つけたり、簡単に仮想マシンイメージを展開したりできます。既存のインストールをLinuxに移行するには、<a href=\"%s\">こちらのドキュメント</a>にいくつかのヒントと移行スクリプトがあります。",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "多くの場合、<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">Webサーバーのルートディレクトリに書き込み権限を与える</a>ことで解決できます。"
 },
 "nplurals=1; plural=0;");
