@@ -1,67 +1,73 @@
 OC.L10N.register(
     "settings",
     {
-    "Security & setup warnings" : "Предупреждения за сигурност и настройки",
-    "Sharing" : "Споделяне",
-    "External Storage" : "Външно Дисково Пространство",
-    "Cron" : "Крон",
-    "Log" : "Лог",
-    "Updates" : "Обновления",
-    "Couldn't remove app." : "Неуспешно премахване на приложението.",
-    "Language changed" : "Езикът е променен",
-    "Invalid request" : "Невалидна заявка",
-    "Authentication error" : "Възникна проблем с идентификацията",
-    "Admins can't remove themself from the admin group" : "Администраторите не могат да премахват себе си от групата \"admin\".",
-    "Unable to add user to group %s" : "Неуспешно добавяне на потребител към групата %s.",
-    "Unable to remove user from group %s" : "Неуспешно премахване на потребител от групата %s.",
-    "Couldn't update app." : "Обновяването на приложението е неуспешно..",
+    "Enabled" : "Включено",
+    "Not enabled" : "Изключено",
     "Wrong password" : "Грешна парола",
-    "No user supplied" : "Липсва потребителско име",
+    "Saved" : "Запаметяване",
+    "No user supplied" : "Липсва потребител",
+    "Unable to change password" : "Неуспешна смяна на паролата.",
+    "Authentication error" : "Възникна проблем с идентификацията",
     "Please provide an admin recovery password, otherwise all user data will be lost" : "Моля, посочете администраторската парола за възстановяване. В противен случай, всичката информация на потребителите ще бъде загубена.",
     "Wrong admin recovery password. Please check the password and try again." : "Грешна администраторска парола за възстановяване. Моля, проверете паролата и опитайте отново.",
     "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Сървърът не позволява смяна на паролата, но потребителския ключ за криптиране беше успешно обновен.",
-    "Unable to change password" : "Неуспешна смяна на паролата.",
-    "Enabled" : "Включено",
-    "Not enabled" : "Изключено",
     "Group already exists." : "Групата вече съществува.",
     "Unable to add group." : "Неуспешно добавяне на група.",
     "Unable to delete group." : "Неуспешно изтриване на група",
-    "log-level out of allowed range" : "Ниво на проследяване \\(log-level\\) e извън допустимия обхват",
-    "Saved" : "Запаметяване",
     "test email settings" : "проверка на настройките на електронна поща",
-    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Настъпи проблем при изпращането на имейла. Моля, провери настройките.  (Грешка: %s)",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Възникна проблем при изпращането на имейла. Моля, провери настройките.  (Грешка: %s)",
     "Email sent" : "Имейлът е изпратен",
-    "You need to set your user email before being able to send test emails." : "Трябва да зададете своя имейл преди да можете да изпращате тестови имейли.",
+    "You need to set your user email before being able to send test emails." : "Трябва да зададете своя имейл за да можете да изпращате тестови имейли.",
+    "Invalid request" : "Невалидна заявка",
     "Invalid mail address" : "невалиден адрес на електронна поща",
     "A user with that name already exists." : "Потребител с това име вече съществува",
     "Unable to create user." : "Неуспешно създаване на потребител.",
     "Your %s account was created" : "Вашия %s профил бе създаден",
     "Unable to delete user." : "Неуспешно изтриване на потребител.",
+    "Settings saved" : "Настройките са запазени",
+    "Unable to change full name" : "Неуспешна промяна на пълното име.",
+    "Your full name has been changed." : "Вашето пълно име е променено.",
     "Forbidden" : "Забранено",
     "Invalid user" : "Невалиден протребител",
     "Unable to change mail address" : "Неуспешна промяна на адрес на електронна поща",
     "Email saved" : "Имейлът е запазен",
-    "Your full name has been changed." : "Вашето пълно име е променено.",
-    "Unable to change full name" : "Неуспешна промяна на пълното име.",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Сигурен/на ли сте, че искате \"{domain}\"  да бъде добавен като сигурен домейн?",
+    "Couldn't remove app." : "Приложението не бе премахнато.",
+    "Admins can't remove themself from the admin group" : "Администраторите не могат да премахват себе си от групата \"admin\".",
+    "Unable to add user to group %s" : "Неуспешно добавяне на потребител към групата %s.",
+    "Unable to remove user from group %s" : "Неуспешно премахване на потребител от групата %s.",
+    "Couldn't update app." : "Приложението не бе обновено.",
     "Add trusted domain" : "Добавяне на сигурен домейн",
     "Sending..." : "Изпращане...",
     "All" : "Всички",
-    "No apps found for your version" : "Няма намерени приложения за вашата версия",
     "Update to %s" : "Обнови до %s",
+    "No apps found for your version" : "Няма намерени приложения за версията, която ползвате",
     "Please wait...." : "Моля, изчакайте....",
-    "Error while disabling app" : "Грешка при изключването на приложението",
+    "Error while disabling app" : "Грешка при изключване на приложението",
     "Disable" : "Изключване",
     "Enable" : "Включване",
     "Error while enabling app" : "Грешка при включване на приложението",
     "Updating...." : "Обновяване...",
-    "Error while updating app" : "Грешка при обновяване на приложението.",
+    "Error while updating app" : "Грешка при обновяване на приложението",
     "Updated" : "Обновено",
     "Uninstalling ...." : "Премахване ...",
     "Error while uninstalling app" : "Грешка при премахването на приложението",
     "Uninstall" : "Премахване",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Google Chrome for Android" : "Google Chrome за Android",
+    "iOS Client" : "iOS клиент",
+    "Android Client" : "Android клиент",
+    "This session" : "Текуща сесия",
+    "Copy" : "Копиране",
+    "Not supported!" : "Не се поддържа!",
+    "Press ⌘-C to copy." : "За копиране натиснете ⌘-C",
+    "Press Ctrl-C to copy." : "За копиране натиснете Ctrl-C",
     "Valid until {date}" : "Далидна до {date}",
     "Delete" : "Изтриване",
+    "Contacts" : "Контакти",
     "Select a profile picture" : "Избиране на профилна снимка",
     "Very weak password" : "Много слаба парола",
     "Weak password" : "Слаба парола",
@@ -73,57 +79,24 @@ OC.L10N.register(
     "A valid group name must be provided" : "Очаква се валидно име на група",
     "deleted {groupName}" : "{groupName} е изтрита",
     "undo" : "възстановяване",
-    "no group" : "няма група",
     "never" : "никога",
     "deleted {userName}" : "{userName}  е изтрит",
-    "add group" : "добавяне на група",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "Промяна на паролата ще доведе до загуба на данни, защото не е налично възстановяване за този потребител.",
     "A valid username must be provided" : "Трябва да бъде зададено валидно потребителско име",
     "A valid password must be provided" : "Трябва да бъде зададена валидна парола",
     "A valid email must be provided" : "Трябва да бъде зададена валидна електронна поща",
     "__language_name__" : "Български",
+    "Unlimited" : "Неограничено",
     "Personal info" : "Лична информация",
+    "Sessions" : "Сесии",
     "Sync clients" : "Синхронизиращи клиенти",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "Всичко (фатални проблеми, грешки, предупреждения, информация, дебъгване)",
-    "Info, warnings, errors and fatal issues" : "информация, предупреждения, грешки и фатални проблеми",
-    "Warnings, errors and fatal issues" : "Предупреждения, грешки и фатални проблеми",
-    "Errors and fatal issues" : "Грешки и фатални проблеми",
-    "Fatal issues only" : "Само фатални проблеми",
     "None" : "Няма",
     "Login" : "Вход",
     "Plain" : "Обикновен",
     "NT LAN Manager" : "NT LAN Manager",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това ще направи няколко основни приложения недостъпни.",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на кеш/акселератор като Zend OPache или eAccelerator.",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Вашия сървър работи на Microsoft Windows. Ние горещо препоръчваме Linux за оптимално потребителско изживяване.",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP модулът 'fileinfo' липсва. Силно препоръчваме този модъл да бъде добавен, за да бъдат постигнати най-добри резултати при mime-type откриването.",
-    "System locale can not be set to a one which supports UTF-8." : "Системните настройки за местоположение не могат да бъдат промени на такива, подържащи UTF-8.",
-    "This means that there might be problems with certain characters in file names." : "Това означва, че може да има проблеми с определини символи в имената на файловете.",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Силно препоръчваме инсталиране на необходимите паките на системата, за поддръжка на следните местоположения: %s.",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ако инсталацията не е в основата на вашия домейн и използва системния cron, могат да възникнат проблеми с генерирането на URLи. За избягване на тези проблеми, моля настройте <code>overwrite.cli.url</code> опцията в config.php файла с мрежовия път към вашята инсталация (Вероятно : \\\"%s\\\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Не бе възможно да изпълним cron задачата през команден интерфейс. Следните технически грешки се появиха:",
-    "Allow apps to use the Share API" : "Разреши приложенията да използват Share API.",
-    "Allow users to share via link" : "Разреши потребителите да споделят с връзка",
-    "Enforce password protection" : "Изискай защита с парола.",
-    "Allow public uploads" : "Разреши общодостъпно качване",
-    "Allow users to send mail notification for shared files" : "Разреши потребителите да изпращат имейл уведомления за споделени файлове.",
-    "Set default expiration date" : "Заложи дата на изтичане по подразбиране",
-    "Expire after " : "Изтечи след",
-    "days" : "дена",
-    "Enforce expiration date" : "Изисквай дата на изтичане",
-    "Allow resharing" : "Разреши пресподеляне.",
-    "Restrict users to only share with users in their groups" : "Ограничи потребителите, така че да могат да споделят само с други потребители в своите групи.",
-    "Allow users to send mail notification for shared files to other users" : "Разреши потребителите да изпращат уведомителни писма за споделени файлове към други потребители.",
-    "Exclude groups from sharing" : "Забрани групи да споделят",
-    "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят.",
-    "Last cron job execution: %s." : "Последно изпълнение на cron задача: %s.",
-    "Last cron job execution: %s. Something seems wrong." : "Последно изпълнение на cron задача: %s. Нещо не е както трябва",
-    "Cron was not executed yet!" : "Cron oще не е изпълнен!",
-    "Execute one task with each page loaded" : "Изпълни по едно задание с всяка заредена страница.",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php е регистриран към webcron да се свързва с cron.php всеки 15 минути по http.",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "Изполвай системната cron service, за връзка с cron.php файла всеки 15 минути.",
+    "SSL/TLS" : "SSL/TLS",
+    "STARTTLS" : "STARTTLS",
+    "Open documentation" : "Отвори документацията",
     "This is used for sending out notifications." : "Това се използва за изпращане на уведомления.",
     "Send mode" : "Режим на изпращане",
     "Encryption" : "Криптиране",
@@ -134,88 +107,146 @@ OC.L10N.register(
     "Server address" : "Адрес на сървъра",
     "Port" : "Порт",
     "Credentials" : "Потр. име и парола",
-    "SMTP Username" : "SMTP Потребителско Име",
-    "SMTP Password" : "SMTP Парола",
+    "SMTP Username" : "SMTP потребител",
+    "SMTP Password" : "SMTP парола",
     "Store credentials" : "Запазвай креденциите",
     "Test email settings" : "Настройки на проверяващия имейл",
     "Send email" : "Изпрати имейл",
-    "Download logfile" : "Изтегли log файла",
-    "More" : "Още",
-    "Less" : "По-малко",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Log файла е по-голям от 100 MB. Изтеглянето му може да отнеме време!",
-    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite е използваната база данни. За по-големи инсталации Ви препоръчваме да изберете друг сървър за бази данни.",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особено, когато използвате клиент за работен плот за синхронизация, използването на SQLite e непрепоръчително.",
+    "Start migration" : "Начало на миграцията",
+    "Security & setup warnings" : "Предупреждения за сигурност и настройки",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това ще направи няколко основни приложения недостъпни.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на кеш/акселератор като Zend OPache или eAccelerator.",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP модулът 'fileinfo' липсва. Силно препоръчваме този модъл да бъде добавен, за да бъдат постигнати най-добри резултати при mime-type откриването.",
+    "System locale can not be set to a one which supports UTF-8." : "Системните настройки за местоположение не могат да бъдат промени на такива, подържащи UTF-8.",
+    "This means that there might be problems with certain characters in file names." : "Това означва, че може да има проблеми с определини символи в имената на файловете.",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Силно препоръчваме инсталиране на необходимите паките на системата, за поддръжка на следните местоположения: %s.",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ако инсталацията не е в основата на вашия домейн и използва системния cron, могат да възникнат проблеми с генерирането на URLи. За избягване на тези проблеми, моля настройте <code>overwrite.cli.url</code> опцията в config.php файла с мрежовия път към вашята инсталация (Вероятно : \\\"%s\\\")",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Изпълнението на cron задачата през командния интерфейс се провали. Появиха се следните грешки:",
+    "Cron" : "Cron",
+    "Last cron job execution: %s." : "Последно изпълнение на cron задача: %s.",
+    "Last cron job execution: %s. Something seems wrong." : "Последно изпълнение на cron задача: %s. Нещо не е както трябва",
+    "Cron was not executed yet!" : "Cron oще не е изпълнен!",
+    "Execute one task with each page loaded" : "Изпълни по едно задание с всяка заредена страница.",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php е регистриран към webcron да се свързва с cron.php всеки 15 минути по http.",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "Изполвай системната cron service, за връзка с cron.php файла всеки 15 минути.",
+    "Version" : "Версия",
+    "Sharing" : "Споделяне",
+    "Allow apps to use the Share API" : "Разреши приложенията да използват Share API",
+    "Allow users to share via link" : "Разреши потребителите да споделят с връзка",
+    "Allow public uploads" : "Разреши общодостъпно качване",
+    "Enforce password protection" : "Изискай защита с парола.",
+    "Set default expiration date" : "Заложи стандартна дата на изтичане",
+    "Expire after " : "Изтечи след",
+    "days" : "дена",
+    "Enforce expiration date" : "Изисквай дата на изтичане",
+    "Allow resharing" : "Разреши пресподеляне.",
+    "Restrict users to only share with users in their groups" : "Ограничи потребителите, така че да могат да споделят само с други потребители в своите групи.",
+    "Exclude groups from sharing" : "Забрани групи да споделят",
+    "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Препоръчително, особено ако ползвате клиента за настолен компютър.",
     "How to do backups" : "Как се правят резервни копия",
     "Advanced monitoring" : "Разширено наблюдение",
     "Performance tuning" : "Настройване на производителност",
     "Improving the config.php" : "Подобряване на config.php",
     "Theming" : "Промяна на облика",
-    "Version" : "Версия",
     "Developer documentation" : "Документация за разработчици",
+    "by %s" : "от %s",
     "Documentation:" : "Документация:",
     "Show description …" : "Покажи описание ...",
     "Hide description …" : "Скрии описание ...",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Това приложение не може да бъде инсталирано, защото следните зависимости не са удовлетворени:",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Приложението не може да бъде инсталирано, защото следните зависимости не са удовлетворени:",
     "Enable only for specific groups" : "Включи само за определени групи",
-    "Uninstall App" : "Премахни Приложението",
+    "Uninstall App" : "Премахни приложението",
     "Common Name" : "Познато Име",
     "Valid until" : "Валиден до",
-    "Issued By" : "Издаден От",
+    "Issued By" : "Издаден от",
     "Valid until %s" : "Валиден до %s",
     "Import root certificate" : "Импортиране на основен сертификат",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Здрасти,<br><br>Само да ти кажа, че имаш %s профил<br><br> Потребителя ти е: %s<br>Достъпи го: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "Поздрави!",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Здрасти,\n\nСамо да ти кажа, че имаш %s профил.\n\nПотребителя ти е: %s\nДостъпи го: %s\n",
     "Forum" : "Форум",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Ползвате <strong>%s</strong> от <strong>%s</strong>",
     "Profile picture" : "Аватар",
     "Upload new" : "Качи нов",
     "Remove image" : "Премахни изображението",
+    "png or jpg, max. 20 MB" : "png или jpg, макс. 20 MB",
     "Cancel" : "Отказ",
     "Full name" : "Пълно име",
     "No display name set" : "Няма настроено екранно име",
     "Email" : "Имейл",
-    "Your email address" : "Твоят имейл адрес",
+    "Your email address" : "Вашият имейл адрес",
     "No email address set" : "Няма настроен адрес на електронна поща",
-    "You are member of the following groups:" : "Ти си член на следните групи:",
+    "Phone number" : "Тел. номер",
+    "Your phone number" : "Вашия тел. номер",
+    "Address" : "Адрес",
+    "Your postal address" : "Вашия пощенски код",
+    "Website" : "Уеб страница",
+    "Your website" : "Вашата уеб страница",
+    "Twitter" : "Twitter",
+    "You are member of the following groups:" : "Член сте на следните групи:",
     "Password" : "Парола",
-    "Unable to change your password" : "Неуспешна промяна на паролата.",
     "Current password" : "Текуща парола",
     "New password" : "Нова парола",
     "Change password" : "Промяна на паролата",
     "Language" : "Език",
-    "Help translate" : "Помогни с превода",
-    "Get the apps to sync your files" : "Изтегли програми за синхронизиране на файловете ти",
+    "Help translate" : "Помогнете с превода",
+    "Get the apps to sync your files" : "Изтеглете програма за синхронизиране на файловете",
     "Desktop client" : "Клиент за настолен компютър",
-    "Android app" : "Андроид приложение",
+    "Android app" : "Android приложение",
     "iOS app" : "iOS приложение",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Ако искаш да помогнеш на проекта:\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\"  rel=\"noreferrer\">присъедини се и пиши код</a>\n\t\tили\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">разпространи мълвата</a>!",
-    "Show First Run Wizard again" : "Покажи Настройките за Първоначално Зареждане отново",
-    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Разработен от {communityopen}Nextcloud общността {linkclose}, {githubopen}изходящия код{linkclose} е лицензиран под {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
-    "Show storage location" : "Покажи място за запис",
+    "Show First Run Wizard again" : "Покажи отново помощника за настройване",
+    "Web, desktop and mobile clients currently logged in to your account." : "Уеб, настолни и мобилни клиенти, които в момента са вписани чрез вашия акаунт.",
+    "Device" : "Устройство",
+    "Last activity" : "Последна активност",
+    "Name" : "Име",
+    "Username" : "Потребител",
+    "Done" : "Завършен",
+    "Show storage location" : "Покажи мястото на хранилището",
     "Show last log in" : "Покажи последно вписване",
     "Send email to new user" : "Изпращай писмо към нов потребител",
     "Show email address" : "Покажи адреса на електронната поща",
-    "Username" : "Потребителско Име",
-    "E-Mail" : "Електронна поща",
+    "E-Mail" : "Имейл",
     "Create" : "Създаване",
-    "Admin Recovery Password" : "Възстановяване на Администраторска Парола",
-    "Enter the recovery password in order to recover the users files during password change" : "Въведи паролата за възстановяване, за да възстановиш файловете на потребителите при промяна на паролата.",
-    "Add Group" : "Добави Група",
-    "Group" : "Група",
+    "Admin Recovery Password" : "Възстановяване на администраторската парола",
+    "Enter the recovery password in order to recover the users files during password change" : "Въведете паролата за възстановяване, за да възстановиш файловете на потребителите при промяна на паролата.",
     "Everyone" : "Всички",
     "Admins" : "Администратори",
-    "Default Quota" : "Квота по подразбиране",
-    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Моля, въведи квота за заделено място (пр. \"512 MB\" или \"12 GB\")",
-    "Unlimited" : "Неограничено",
+    "Default quota" : "Стандартна квота",
+    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Моля, въведете квота за хранилището (напр. \"512 MB\" или \"12 GB\")",
     "Other" : "Друга...",
-    "Full Name" : "Пълно Име",
-    "Group Admin for" : "Групов администратор за",
     "Quota" : "Квота",
-    "Storage Location" : "Място за Запис",
-    "Last Login" : "Последно Вписване",
+    "Storage location" : "Дисково пространство",
+    "Last login" : "Последно вписване",
     "change full name" : "промени пълното име",
     "set new password" : "сложи нова парола",
     "change email address" : "Смени адреса на елетронната поща",
-    "Default" : "По подразбиране"
+    "Default" : "Стандарт",
+    "log-level out of allowed range" : "Ниво на проследяване \\(log-level\\) e извън допустимия обхват",
+    "Language changed" : "Езикът е променен",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Сигурен/на ли сте, че искате \"{domain}\"  да бъде добавен като сигурен домейн?",
+    "iPhone" : "iPhone",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "Всичко (фатални проблеми, грешки, предупреждения, информация, дебъгване)",
+    "Info, warnings, errors and fatal issues" : "информация, предупреждения, грешки и фатални проблеми",
+    "Warnings, errors and fatal issues" : "Предупреждения, грешки и фатални проблеми",
+    "Errors and fatal issues" : "Грешки и фатални проблеми",
+    "Fatal issues only" : "Само фатални проблеми",
+    "Log" : "Журнал",
+    "Download logfile" : "Изтегли журнала",
+    "More" : "Още",
+    "Less" : "По-малко",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Журнала е по-голям от 100 MB. Изтеглянето му може да отнеме време!",
+    "Allow users to send mail notification for shared files" : "Разреши на потребителите да изпращат имейл уведомления за споделени файлове.",
+    "Allow users to send mail notification for shared files to other users" : "Разреши на потребителите да изпращат уведомителни писма за споделени файлове към други потребители.",
+    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite е използваната база данни. За по-големи инсталации Ви препоръчваме да изберете друг сървър за бази данни.",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Използването на SQLite не се препоръчва, особено ако ползвате клиента за настолен компютър.",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Здрасти,<br><br>Само да ти кажа, че имаш %s профил<br><br> Потребителя ти е: %s<br>Достъпи го: <a href=\"%s\">%s</a><br><br>",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Здрасти,\n\nСамо да ти кажа, че имаш %s профил.\n\nПотребителя ти е: %s\nДостъпи го: %s\n",
+    "Group" : "Група",
+    "Default Quota" : "Стандартна квота",
+    "Storage Location" : "Дисково пространство",
+    "Last Login" : "Последно вписване",
+    "Redis" : "Redis",
+    "External Storage" : "Външно хранилище",
+    "Updates" : "Обновления",
+    "An error occurred: {message}" : "Възникна грешка: {message}"
 },
 "nplurals=2; plural=(n != 1);");
