@@ -1,77 +1,65 @@
 OC.L10N.register(
     "settings",
     {
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Security & setup warnings" : "คำเตือนความปลอดภัยและการติดตั้ง",
-    "Sharing" : "การแชร์ข้อมูล",
-    "Server-side encryption" : "เข้ารหัสฝั่งเซิร์ฟเวอร์",
-    "External Storage" : "พื้นทีจัดเก็บข้อมูลจากภายนอก",
-    "Cron" : "Cron",
-    "Email server" : "อีเมลเซิร์ฟเวอร์",
-    "Log" : "บันทึกการเปลี่ยนแปลง",
-    "Tips & tricks" : "เคล็ดลับและเทคนิค",
-    "Updates" : "อัพเดท",
-    "Couldn't remove app." : "ไม่สามารถลบแอพฯ",
-    "Language changed" : "เปลี่ยนภาษาเรียบร้อยแล้ว",
-    "Invalid request" : "คำร้องขอไม่ถูกต้อง",
-    "Authentication error" : "เกิดข้อผิดพลาดในสิทธิ์การเข้าใช้งาน",
-    "Admins can't remove themself from the admin group" : "ผู้ดูแลระบบไม่สามารถลบตัวเองออกจากกลุ่มผู้ดูแลได้",
-    "Unable to add user to group %s" : "ไม่สามารถเพิ่มผู้ใช้งานเข้าไปที่กลุ่ม %s ได้",
-    "Unable to remove user from group %s" : "ไม่สามารถลบผู้ใช้งานออกจากกลุ่ม %s ได้",
-    "Couldn't update app." : "ไม่สามารถอัพเดทแอปฯ",
-    "Wrong password" : "รหัสผ่านไม่ถูกต้อง",
-    "No user supplied" : "ไม่มีผู้ใช้",
-    "Please provide an admin recovery password, otherwise all user data will be lost" : "โปรดให้กู้คืนรหัสผ่านของผู้ดูแลระบบมิฉะนั้นข้อมูลของผู้ใช้ทั้งหมดจะหายไป",
-    "Wrong admin recovery password. Please check the password and try again." : "กู้คืนรหัสผ่านของผู้ดูแลระบบไม่ถูกต้อง กรุณาตรวจสอบรหัสผ่านและลองอีกครั้ง.",
-    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "แบ็กเอนด์ไม่สนับสนุนการเปลี่ยนแปลงรหัสผ่าน แต่คีย์การเข้ารหัสลับของผู้ใช้จะถูกอัพเดทสำเร็จ",
-    "Unable to change password" : "ไม่สามารถเปลี่ยนรหัสผ่าน",
     "Enabled" : "เปิดการใช้งาน",
     "Not enabled" : "ใช้งานไม่ได้",
+    "Wrong password" : "รหัสผ่านไม่ถูกต้อง",
+    "Saved" : "บันทึกแล้ว",
+    "No user supplied" : "ไม่มีผู้ใช้",
+    "Unable to change password" : "ไม่สามารถเปลี่ยนรหัสผ่าน",
+    "Authentication error" : "เกิดข้อผิดพลาดในสิทธิ์การเข้าใช้งาน",
+    "Please provide an admin recovery password, otherwise all user data will be lost" : "โปรดให้กู้คืนรหัสผ่านของผู้ดูแลระบบมิฉะนั้นข้อมูลของผู้ใช้ทั้งหมดจะหายไป",
+    "Wrong admin recovery password. Please check the password and try again." : "กู้คืนรหัสผ่านของผู้ดูแลระบบไม่ถูกต้อง กรุณาตรวจสอบรหัสผ่านและลองอีกครั้ง.",
+    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "แบ็กเอนด์ไม่สนับสนุนการเปลี่ยนแปลงรหัสผ่าน แต่คีย์ที่เข้ารหัสลับของผู้ใช้ได้ถูกอัพเดทแล้ว",
     "installing and updating apps via the app store or Federated Cloud Sharing" : "กำลังติดตั้งและอัพเดทแอพพลิเคชันผ่าแอพสโตร์หรือคลาวด์ในเครือ",
-    "Federated Cloud Sharing" : "สหพันธ์การแชร์คลาวด์",
-    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL รุ่น %s เป็นรุ่นเก่า (%s)โปรดอัพเดทระบบปฏิบัติการหรือคุณสมบัติเป็น %s เพื่อการทำงานที่มีประสิทธิภาพ",
-    "A problem occurred, please check your log files (Error: %s)" : "มีปัญหาเกิดขึ้นโปรดตรวจสอบบันทึกไฟล์ของคุณ (ข้อผิดพลาด: %s)",
+    "Federated Cloud Sharing" : "แชร์กับสหพันธ์คลาวด์",
+    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "คุณกำลังใช้ cURL %s รุ่นเก่ากว่า (%s)โปรดอัพเดทระบบปฏิบัติการหรือคุณสมบัติเป็น %s เพื่อการทำงานที่มีประสิทธิภาพ",
+    "A problem occurred, please check your log files (Error: %s)" : "มีปัญหาเกิดขึ้นโปรดตรวจสอบไฟล์บันทึกของคุณ (ข้อผิดพลาด: %s)",
     "Migration Completed" : "การโยกย้ายเสร็จสมบูรณ์",
     "Group already exists." : "มีกลุ่มนี้อยู่แล้ว",
     "Unable to add group." : "ไม่สามารถเพิ่มกลุ่ม",
     "Unable to delete group." : "ไม่สามารถลบกลุ่ม",
-    "log-level out of allowed range" : "ระดับ-บันทึก ไม่ได้อยู่ในช่วงที่ได้รับอนุญาต",
-    "Saved" : "บันทึกแล้ว",
-    "test email settings" : "การตั้งค่าอีเมลทดสอบ",
+    "test email settings" : "ทดสอบการตั้งค่าอีเมล",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "เกิดปัญหาขึ้นในขณะที่ส่งอีเมล กรุณาแก้ไขการตั้งค่าของคุณ (ข้อผิดพลาด: %s)",
     "Email sent" : "ส่งอีเมลแล้ว",
     "You need to set your user email before being able to send test emails." : "คุณจำเป็นต้องตั้งค่าอีเมลผู้ใช้ของคุณก่อนที่จะสามารถส่งอีเมลทดสอบ",
+    "Invalid request" : "คำร้องขอไม่ถูกต้อง",
     "Invalid mail address" : "ที่อยู่อีเมลไม่ถูกต้อง",
     "A user with that name already exists." : "มีชื้อผู้ใช้นี้อยู่แล้ว",
     "Unable to create user." : "ไม่สามารถสร้างผู้ใช้",
     "Your %s account was created" : "บัญชี %s ของคุณถูกสร้างขึ้น",
     "Unable to delete user." : "ไม่สามารถลบผู้ใช้",
+    "Unable to change full name" : "ไม่สามารถเปลี่ยนชื่อเต็ม",
+    "Your full name has been changed." : "ชื่อเต็มของคุณถูกเปลี่ยนแปลง",
     "Forbidden" : "เขตหวงห้าม",
     "Invalid user" : "ผู้ใช้ไม่ถูกต้อง",
     "Unable to change mail address" : "ไม่สามารถที่จะเปลี่ยนที่อยู่อีเมล",
     "Email saved" : "อีเมลถูกบันทึกแล้ว",
-    "Your full name has been changed." : "ชื่อเต็มของคุณถูกเปลี่ยนแปลง",
-    "Unable to change full name" : "ไม่สามารถเปลี่ยนชื่อเต็ม",
-    "Are you really sure you want add \"{domain}\" as trusted domain?" : "คุณแน่ใจจริงๆ ว่าคุณต้องการเพิ่ม \"{domain}\" เป็นโดเมนที่เชื่อถือได้?",
+    "Couldn't remove app." : "ไม่สามารถลบแอพฯ",
+    "Admins can't remove themself from the admin group" : "ผู้ดูแลระบบไม่สามารถลบตัวเองออกจากกลุ่มผู้ดูแลได้",
+    "Unable to add user to group %s" : "ไม่สามารถเพิ่มผู้ใช้งานเข้าไปที่กลุ่ม %s ได้",
+    "Unable to remove user from group %s" : "ไม่สามารถลบผู้ใช้งานออกจากกลุ่ม %s ได้",
+    "Couldn't update app." : "ไม่สามารถอัพเดทแอปฯ",
     "Add trusted domain" : "เพิ่มโดเมนที่เชื่อถือได้",
     "Migration in progress. Please wait until the migration is finished" : "ในระหว่างดำเนินการโยกย้าย กรุณารอสักครู่จนกว่าการโยกย้ายจะเสร็จสิ้น",
     "Migration started …" : "เริ่มต้นการโยกย้าย …",
     "Sending..." : "กำลังส่ง...",
     "Official" : "เป็นทางการ",
-    "Approved" : "ได้รับการอนุมัติ",
-    "Experimental" : "การทดลอง",
     "All" : "ทั้งหมด",
+    "Update to %s" : "อัพเดทไปยัง %s",
+    "_You have %n app update pending_::_You have %n app updates pending_" : ["คุณมีอัพเดทแอพฯ n% รายการ อยู่ในระหว่างดำเนินการ"],
     "No apps found for your version" : "ไม่พบแอพพลิเคชันสำหรับรุ่นของคุณ",
-    "Official apps are developed by and within the Nextcloud community. They offer functionality central to Nextcloud and are ready for production use." : "แอพพลิเคชันมีการพัฒนาอย่างเป็นทางการภายในชุมชน Nextcloud พวกเขามีการทำงานเป็นศูนย์กลางของ Nextcloud และพร้อมสำหรับการใช้งานผลิตภัณฑ์",
+    "The app will be downloaded from the app store" : "แอพฯจะดาวน์โหลดได้จากแอพสโตร์",
     "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "แอพพลิเคชันได้รับการอนุมัติและพัฒนาโดยนักพัฒนาที่น่าเชื่อถือและได้ผ่านการตรวจสอบความปลอดภัยคร่าวๆ พวกเขาจะได้รับการบำรุงรักษาอย่างดีในการเก็บข้อมูลรหัสเปิด มันอาจยังไม่เสถียรพอสำหรับการเปิดใช้งานปกติ",
     "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "แอพฯ นี้ไม่ได้ตรวจสอบปัญหาด้านความปลอดภัยและเป็นแอพฯใหม่หรือที่รู้จักกันคือจะไม่เสถียร ติดตั้งบนความเสี่ยงของคุณเอง",
-    "Update to %s" : "อัพเดทไปยัง %s",
     "Please wait...." : "กรุณารอสักครู่...",
     "Error while disabling app" : "เกิดข้อผิดพลาดขณะปิดการใช้งานแอพพลิเคชัน",
     "Disable" : "ปิดใช้งาน",
     "Enable" : "เปิดใช้งาน",
     "Error while enabling app" : "เกิดข้อผิดพลาดขณะกำลังตรวจสอบแอพฯ",
+    "Error: this app cannot be enabled because it makes the server unstable" : "ข้อผิดพลาด: ไม่สามารถเปิดใช้งานแอพฯนี้ เพราะมันอาจทำให้เซิร์ฟเวอร์มีปัญหา",
+    "Error: could not disable broken app" : "ข้อผิดพลาด: ไม่สามารถปิดการใช้งานแอพฯที่มีปัญหา",
+    "Error while disabling broken app" : "ข้อผิดพลาดขณะกำลังปิดการใช้งานแอพฯที่มีปัญหา",
     "Updating...." : "กำลังอัพเดทข้อมูล...",
     "Error while updating app" : "เกิดข้อผิดพลาดขณะกำลังอัพเดทแอพฯ",
     "Updated" : "อัพเดทแล้ว",
@@ -80,11 +68,12 @@ OC.L10N.register(
     "Uninstall" : "ถอนการติดตั้ง",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "แอพฯจะต้องเปิดใช้งานก่อนทำการอัพเดท คุณจะถูกนำไปยังหน้าอัพเดทใน 5 วินาที",
     "App update" : "อัพเดทแอพฯ",
-    "No apps found for \"{query}\"" : "ไม่พบแอพฯสำหรับ \"{query}\"",
+    "Approved" : "ได้รับการอนุมัติ",
+    "Experimental" : "การทดลอง",
+    "No apps found for {query}" : "ไม่พบแอพฯสำหรับ {query}",
     "An error occurred. Please upload an ASCII-encoded PEM certificate." : "เกิดข้อผิดพลาด กรุณาอัพโหลดใบรับรองเข้ารหัส ASCII PEM",
     "Valid until {date}" : "ใช้ได้จนถึงวันที่ {date}",
     "Delete" : "ลบ",
-    "An error occurred: {message}" : "เกิดข้อผิดพลาด: {message}",
     "Select a profile picture" : "เลือกรูปภาพโปรไฟล์",
     "Very weak password" : "รหัสผ่านระดับต่ำมาก",
     "Weak password" : "รหัสผ่านระดับต่ำ",
@@ -93,81 +82,27 @@ OC.L10N.register(
     "Strong password" : "รหัสผ่านระดับดีมาก",
     "Groups" : "กลุ่ม",
     "Unable to delete {objName}" : "ไม่สามารถลบ {objName}",
+    "Error creating group: {message}" : "ข้อผิดพลาดการสร้างกลุ่ม: {message}",
     "A valid group name must be provided" : "จะต้องระบุชื่อกลุ่มที่ถูกต้อง",
     "deleted {groupName}" : "ลบกลุ่ม {groupName} เรียบร้อยแล้ว",
     "undo" : "เลิกทำ",
-    "no group" : "ไม่มีกลุ่ม",
     "never" : "ไม่ต้องเลย",
     "deleted {userName}" : "ลบผู้ใช้ {userName} เรียบร้อยแล้ว",
-    "add group" : "เพิ่มกลุ่ม",
     "Changing the password will result in data loss, because data recovery is not available for this user" : "การเปลี่ยนรหัสผ่านจะส่งผลให้เกิดการสูญเสียข้อมูลเพราะการกู้คืนข้อมูลจะไม่สามารถใช้ได้สำหรับผู้ใช้นี้",
     "A valid username must be provided" : "จะต้องระบุชื่อผู้ใช้ที่ถูกต้อง",
+    "Error creating user: {message}" : "ข้อผิดพลาดในการสร้างผู้ใช้: {message}",
     "A valid password must be provided" : "จะต้องระบุรหัสผ่านที่ถูกต้อง",
     "A valid email must be provided" : "จะต้องระบุอีเมลที่ถูกต้อง",
     "__language_name__" : "ภาษาไทย - Thai languages",
+    "Unlimited" : "ไม่จำกัด",
     "Personal info" : "ข้อมูลส่วนบุคคล",
     "Sync clients" : "ประสานข้อมูลไคลเอนต์",
-    "Everything (fatal issues, errors, warnings, info, debug)" : "ทุกอย่าง (ปัญหาร้ายแรง ข้อผิดพลาด คำเตือน ข้อมูล การแก้ปัญหา)",
-    "Info, warnings, errors and fatal issues" : "ข้อมูล คำเตือน ข้อผิดพลาดและปัญหาร้ายแรง",
-    "Warnings, errors and fatal issues" : "คำเตือนข้อผิดพลาดและปัญหาที่ร้ายแรง",
-    "Errors and fatal issues" : "ข้อผิดพลาดและปัญหาที่ร้ายแรง",
-    "Fatal issues only" : "ปัญหาร้ายแรงเท่านั้น",
     "None" : "ไม่มี",
     "Login" : "เข้าสู่ระบบ",
     "Plain" : "ธรรมดา",
     "NT LAN Manager" : "ตัวจัดการ NT LAN",
-    "SSL" : "SSL",
-    "TLS" : "TLS",
-    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "ไม่ได้ติดตั้งphp อย่างถูกต้องค้นหาตัวแปรสภาพแวดล้อมของระบบการทดสอบกับ getenv(\"PATH\") ส่งกลับเฉพาะการตอบสนองที่ว่างเปล่า",
-    "Please check the <a target=\"_blank\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "กรุณาตรวจสอบ <a target=\"_blank\" href=\"%s\">เอกสารการติดตั้ง</a> สำหรับการตั้งค่าและบันทึก php ของเซิร์ฟเวอร์ของคุณโดยเฉพาะอย่างยิ่งเมื่อใช้ php-fpm",
-    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "ตั้งค่าให้สามารถอ่านได้อย่างเดียวถูกเปิดใช้งาน นี้จะช่วยป้องกันการตั้งค่าผ่านทางบางเว็บอินเตอร์เฟซ นอกจากนี้จะต้องเขียนไฟล์ด้วยตนเองสำหรับทุกการอัพเดท",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "เห็นได้ชัดว่าการตั้งค่า PHP จะตัดบล็อคเอกสารแบบอินไลน์ ซึ่งจะทำให้แอพพลิเคชันอีกหลายแกนไม่สามารถเข้าถึงได้",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "นี้อาจเกิดจาก cache/accelerator อย่างเช่น Zend OPcache หรือ eAccelerator",
-    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "เซิร์ฟเวอร์ของคุณทำงานบน Microsoft Windows เราขอแนะนำให้ใช้ลินุกซ์หากคุณต้องการ การใช้งานที่ดีที่สุด",
-    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "โมดูล PHP 'fileinfo' หายไป เราขอแนะนำให้เปิดใช้งานโมดูลนี้เพื่อให้ได้ผลลัพธ์ที่ดีที่สุดกับการตรวจสอบชนิด mime",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" href=\"%s\">documentation ↗</a> for more information." : "การทำธุรกรรมล็อคไฟล์ถูกปิดใช้งาน มันอาจเป็นปัญหา ให้เปิดใช้งาน 'filelocking.enabled' ใน config.php เพื่อหลีกเลี่ยงปัญหาเหล่านี้ ดูเพิ่มเติมได้จาก <a target=\"_blank\" href=\"%s\">เอกสาร</a>",
-    "System locale can not be set to a one which supports UTF-8." : "ตำแหน่งที่ตั้งของระบบไม่สามารถตั้งค่าให้รองรับ UTF-8",
-    "This means that there might be problems with certain characters in file names." : "นี้หมายความว่าอาจจะมีปัญหากับตัวอักษรบางตัวในชื่อไฟล์",
-    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "เราขอแนะนำให้ติดตั้งแพคเกจที่จำเป็นต้องใช้ในระบบของคุณ ให้การสนับสนุนตำแหน่งที่ตั้งดังต่อไปนี้: %s",
-    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "หากการติดตั้งของคุณไม่ได้ติดตั้งในรากของโดเมนและใช้ระบบ cron อาจมีปัญหาเกี่ยวกับการสร้าง URL เพื่อหลีกเลี่ยงปัญหาเหล่านี้โปรดไปตั้งค่า \"overwrite.cli.url\" ในไฟล์ config.php ของคุณไปยังเส้นทาง webroot ของการติดตั้งของคุณ (แนะนำ: \"%s\")",
-    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "มันเป็นไปไม่ได้ที่จะดำเนินการ cronjob ผ่านทาง CLI ข้อผิดพลาดทางเทคนิคต่อไปนี้จะปรากฏ:",
-    "Please double check the <a target=\"_blank\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "กรุณาตรวจสอบ <a target=\"_blank\" href=\"%s\">คู่มือการติดตั้ง</a> และตรวจสอบข้อผิดพลาดหรือคำเตือนใน <a href=\"#log-section\">บันทึก</a>",
-    "All checks passed." : "ผ่านการตรวจสอบทั้งหมด",
+    "Email server" : "อีเมลเซิร์ฟเวอร์",
     "Open documentation" : "เปิดเอกสาร",
-    "Allow apps to use the Share API" : "อนุญาตให้แอปฯสามารถใช้ API สำหรับแชร์ข้อมูลได้",
-    "Allow users to share via link" : "อนุญาตให้ผู้ใช้สามารถแชร์ผ่านทางลิงค์",
-    "Enforce password protection" : "บังคับใช้การป้องกันรหัสผ่าน",
-    "Allow public uploads" : "อนุญาตให้อัพโหลดสาธารณะ",
-    "Allow users to send mail notification for shared files" : "อนุญาตให้ผู้ใช้ส่งการแจ้งเตือนอีเมลสำหรับไฟล์ที่ถูกแชร์",
-    "Set default expiration date" : "ตั้งค่าเริ่มต้นวันหมดอายุ",
-    "Expire after " : "หมดอายุหลังจาก",
-    "days" : "วัน",
-    "Enforce expiration date" : "บังคับให้มีวันที่หมดอายุ",
-    "Allow resharing" : "อนุญาตให้แชร์ข้อมูลซ้ำใหม่ได้",
-    "Restrict users to only share with users in their groups" : "จำกัดให้ผู้ใช้สามารถแชร์กับผู้ใช้ในกลุ่มของพวกเขาเท่านั้น",
-    "Allow users to send mail notification for shared files to other users" : "อนุญาตให้ผู้ใช้ส่งการแจ้งเตือนอีเมลสำหรับไฟล์ที่แชร์กับผู้ใช้อื่นๆ",
-    "Exclude groups from sharing" : "ไม่รวมกลุ่มที่แชร์",
-    "These groups will still be able to receive shares, but not to initiate them." : "กลุ่มนี้จะยังคงสามารถได้รับการแชร์ แต่พวกเขาจะไม่รู้จักมัน",
-    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "อนุญาตให้เติมชื่อผู้ใช้ในกล่องตอบโต้อัตโนมัติ ถ้านี้ถูกปิดใช้งานชื่อผู้ใช้จะต้องกรอกเอง",
-    "Last cron job execution: %s." : "การดำเนินการ cron job ล่าสุด: %s",
-    "Last cron job execution: %s. Something seems wrong." : "การดำเนินการ cron job ล่าสุด: %s ดูเหมือนมีบางสิ่งไม่ถูกต้อง",
-    "Cron was not executed yet!" : "Cron ไม่ได้ถูกดำเนินการ!",
-    "Execute one task with each page loaded" : "ประมวลคำสั่งหนึ่งงานในแต่ละครั้งที่มีการโหลดหน้าเว็บ",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php มีการลงทะเบียนให้บริการ Webcron เรียก cron.php ทุกๆ 15 นาที บน Http",
-    "Use system's cron service to call the cron.php file every 15 minutes." : "บริการ cron ของระบบจะเรียกไฟล์ cron.php ทุกq 15 นาที",
-    "Enable server-side encryption" : "เปิดการใช้งานเข้ารหัสฝั่งเซิร์ฟเวอร์",
-    "Please read carefully before activating server-side encryption: " : "กรุณาอ่านอย่างละเอียดก่อนที่จะเปิดใช้งานการเข้ารหัสฝั่งเซิร์ฟเวอร์:",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "เมื่อเปิดใช้งานการเข้ารหัส ไฟล์ทั้งหมดที่อัพโหลดไปยังเซิร์ฟเวอร์นั้นจะถูกเข้ารหัสในส่วนของเซิฟเวอร์ มันเป็นไปได้ที่จะปิดใช้งานการเข้ารหัสในภายหลัง ถ้าเปิดใช้ฟังก์ชั่นการสนับสนุนโมดูลการเข้ารหัสที่และเงื่อนไขก่อน (เช่น การตั้งค่าคีย์กู้คืน)",
-    "Encryption alone does not guarantee security of the system. Please see Nextcloud documentation for more information about how the encryption app works, and the supported use cases." : "การเข้ารหัสลับเพียงอย่างเดียวไม่ได้รับประกันความปลอดภัยของระบบ โปรดดูเอกสาร Nextcloud สำหรับข้อมูลเพิ่มเติมเกี่ยวกับวิธีการเข้ารหัสแอพพลิเคชันและกรณีการสนับสนุน",
-    "Be aware that encryption always increases the file size." : "โปรดทราบว่าหากเข้ารหัสไฟล์จะทำให้ขนาดของไฟล์ใหญ่ขึ้น",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "มันจะดีถ้าคุณสำรองข้อมูลบ่อยๆ ในกรณีของการเข้ารหัสโปรดแน่ใจว่าจะสำรองคีย์การเข้ารหัสลับพร้อมกับข้อมูลของคุณ",
-    "This is the final warning: Do you really want to enable encryption?" : "นี่คือการเตือนครั้งสุดท้าย: คุณต้องการที่จะเปิดใช้การเข้ารหัส?",
-    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "ไม่มีโมดูลการเข้ารหัสโหลดโปรดเปิดใช้งานโมดูลการเข้ารหัสในเมนูแอพฯ",
-    "Select default encryption module:" : "เลือกค่าเริ่มต้นโมดูลการเข้ารหัส:",
-    "You need to migrate your encryption keys from the old encryption (Nextcloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "คุณจำเป็นต้องโอนย้ายคีย์การเข้ารหัสลับของคุณจากการเข้ารหัสเก่า (Nextcloud <= 8.0) ไปใหม่ กรุณาเปิดใช้งาน \"โมดูลการเข้ารหัสเริ่มต้น\" และเรียกใช้ 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (Nextcloud <= 8.0) to the new one." : "คุณจำเป็นต้องโอนย้ายคีย์การเข้ารหัสลับของคุณจากการเข้ารหัสเก่า (Nextcloud <= 8.0) ไปใหม่",
-    "Start migration" : "เริ่มการโยกย้าย",
     "This is used for sending out notifications." : "นี้จะใช้สำหรับการส่งออกการแจ้งเตือน",
     "Send mode" : "โหมดการส่ง",
     "Encryption" : "การเข้ารหัส",
@@ -181,26 +116,65 @@ OC.L10N.register(
     "SMTP Username" : "ชื่อผู้ใช้ SMTP",
     "SMTP Password" : "รหัสผ่าน SMTP",
     "Store credentials" : "ข้อมูลประจำตัวของร้านค้า",
-    "Test email settings" : "การตั้งค่าอีเมลทดสอบ",
+    "Test email settings" : "ทดสอบการตั้งค่าอีเมล",
     "Send email" : "ส่งอีเมล",
-    "Download logfile" : "ดาวน์โหลดไฟล์บันทึก",
-    "More" : "มาก",
-    "Less" : "น้อย",
-    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "ไฟล์บันทึกมีขนาดใหญ่กว่า 100 เมกะไบต์ มันอาจจะใช้เวลาดาวน์โหลดนาน!",
-    "What to log" : "อะไรที่จะบันทึก",
-    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "จะใช้ SQLite เป็นฐานข้อมูล สำหรับการติดตั้งขนาดใหญ่เราขอแนะนำเพื่อสลับไปยังฐานข้อมูลแบ็กเอนด์ที่แตกต่างกัน",
-    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "โดยเฉพาะอย่างยิ่งเมื่อใช้ไคลเอนต์เดสก์ทอปสำหรับการประสานข้อมูลโดย SQLite",
-    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" href=\"%s\">documentation ↗</a>." : "การโยกย้ายไปยังฐานข้อมูลอื่นใช้เครื่องมือบรรทัดคำสั่ง: 'occ db:convert-type' หรือดูที่ <a target=\"_blank\" href=\"%s\">เอกสาร</a>",
+    "Server-side encryption" : "เข้ารหัสฝั่งเซิร์ฟเวอร์",
+    "Enable server-side encryption" : "เปิดการใช้งานเข้ารหัสฝั่งเซิร์ฟเวอร์",
+    "Please read carefully before activating server-side encryption: " : "กรุณาอ่านอย่างละเอียดก่อนที่จะเปิดใช้งานการเข้ารหัสฝั่งเซิร์ฟเวอร์:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "เมื่อเปิดใช้งานการเข้ารหัส ไฟล์ทั้งหมดที่อัพโหลดไปยังเซิร์ฟเวอร์นั้นจะถูกเข้ารหัสในส่วนของเซิฟเวอร์ มันเป็นไปได้ที่จะปิดใช้งานการเข้ารหัสในภายหลัง ถ้าเปิดใช้ฟังก์ชั่นการสนับสนุนโมดูลการเข้ารหัสที่และเงื่อนไขก่อน (เช่น การตั้งค่าคีย์กู้คืน)",
+    "Be aware that encryption always increases the file size." : "โปรดทราบว่าหากเข้ารหัสไฟล์จะทำให้ขนาดของไฟล์ใหญ่ขึ้น",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "มันจะดีถ้าคุณสำรองข้อมูลบ่อยๆ ในกรณีของการเข้ารหัสโปรดแน่ใจว่าจะสำรองคีย์การเข้ารหัสลับพร้อมกับข้อมูลของคุณ",
+    "This is the final warning: Do you really want to enable encryption?" : "นี่คือการเตือนครั้งสุดท้าย: คุณต้องการที่จะเปิดใช้การเข้ารหัส?",
+    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "ไม่มีโมดูลการเข้ารหัสโหลดโปรดเปิดใช้งานโมดูลการเข้ารหัสในเมนูแอพฯ",
+    "Select default encryption module:" : "เลือกค่าเริ่มต้นโมดูลการเข้ารหัส:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "คุณจำเป็นต้องโอนย้ายคีย์การเข้ารหัสลับของคุณจากการเข้ารหัสเก่า (ownCloud <= 8.0) ไปใหม่ กรุณาเปิดใช้งาน \"โมดูลการเข้ารหัสเริ่มต้น\" และเรียกใช้ 'occ encryption:migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "คุณจำเป็นต้องโอนย้ายคีย์การเข้ารหัสลับของคุณจากการเข้ารหัสเก่า (ownCloud <= 8.0) ไปใหม่",
+    "Start migration" : "เริ่มการโยกย้าย",
+    "Security & setup warnings" : "คำเตือนความปลอดภัยและการติดตั้ง",
+    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "ไม่ได้ติดตั้งphp อย่างถูกต้องค้นหาตัวแปรสภาพแวดล้อมของระบบการทดสอบกับ getenv(\"PATH\") ส่งกลับเฉพาะการตอบสนองที่ว่างเปล่า",
+    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "ตั้งค่าให้สามารถอ่านได้อย่างเดียวถูกเปิดใช้งาน นี้จะช่วยป้องกันการตั้งค่าผ่านทางบางเว็บอินเตอร์เฟซ นอกจากนี้จะต้องเขียนไฟล์ด้วยตนเองสำหรับทุกการอัพเดท",
+    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "เห็นได้ชัดว่าการตั้งค่า PHP จะตัดบล็อคเอกสารแบบอินไลน์ ซึ่งจะทำให้แอพพลิเคชันอีกหลายแกนไม่สามารถเข้าถึงได้",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "นี้อาจเกิดจาก cache/accelerator อย่างเช่น Zend OPcache หรือ eAccelerator",
+    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s เป็นรุ่นที่ต่ำกว่า %2$s ได้ถูกติดตั้ง สำหรับเหตุผลด้านเสถียรภาพและประสิทธิภาพการทำงาน เราขอแนะนำให้อัพเดทไปเป็นรุ่น %1$s",
+    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "โมดูล PHP 'fileinfo' หายไป เราขอแนะนำให้เปิดใช้งานโมดูลนี้เพื่อให้ได้ผลลัพธ์ที่ดีที่สุดกับการตรวจสอบชนิด mime",
+    "System locale can not be set to a one which supports UTF-8." : "ตำแหน่งที่ตั้งของระบบไม่สามารถตั้งค่าให้รองรับ UTF-8",
+    "This means that there might be problems with certain characters in file names." : "นี้หมายความว่าอาจจะมีปัญหากับตัวอักษรบางตัวในชื่อไฟล์",
+    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "เราขอแนะนำให้ติดตั้งแพคเกจที่จำเป็นต้องใช้ในระบบของคุณ ให้การสนับสนุนตำแหน่งที่ตั้งดังต่อไปนี้: %s",
+    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "หากการติดตั้งของคุณไม่ได้ติดตั้งในรากของโดเมนและใช้ระบบ cron อาจมีปัญหาเกี่ยวกับการสร้าง URL เพื่อหลีกเลี่ยงปัญหาเหล่านี้โปรดไปตั้งค่า \"overwrite.cli.url\" ในไฟล์ config.php ของคุณไปยังเส้นทาง webroot ของการติดตั้งของคุณ (แนะนำ: \"%s\")",
+    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "มันเป็นไปไม่ได้ที่จะดำเนินการ cronjob ผ่านทาง CLI ข้อผิดพลาดทางเทคนิคต่อไปนี้จะปรากฏ:",
+    "All checks passed." : "ผ่านการตรวจสอบทั้งหมด",
+    "Cron" : "Cron",
+    "Last cron job execution: %s." : "การดำเนินการ cron job ล่าสุด: %s",
+    "Last cron job execution: %s. Something seems wrong." : "การดำเนินการ cron job ล่าสุด: %s ดูเหมือนมีบางสิ่งไม่ถูกต้อง",
+    "Cron was not executed yet!" : "Cron ไม่ได้ถูกดำเนินการ!",
+    "Execute one task with each page loaded" : "ประมวลผลหนึ่งงาน ในแต่ละครั้งที่มีการโหลดหน้าเว็บ",
+    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php ได้ถูกลงทะเบียนที่บริการ Webcron เพื่อเรียก cron.php ทุกๆ 15 นาที บน Http",
+    "Use system's cron service to call the cron.php file every 15 minutes." : "ใช้ระบบบริการ cron เพื่อเรียกไฟล์ cron.php ทุก 15 นาที",
+    "Version" : "รุ่น",
+    "Sharing" : "แชร์ข้อมูล",
+    "Allow apps to use the Share API" : "อนุญาตให้แอปฯสามารถใช้ API สำหรับแชร์ข้อมูลได้",
+    "Allow users to share via link" : "อนุญาตให้ผู้ใช้สามารถแชร์ผ่านทางลิงค์",
+    "Allow public uploads" : "อนุญาตให้อัพโหลดสาธารณะ",
+    "Enforce password protection" : "บังคับใช้การป้องกันรหัสผ่าน",
+    "Set default expiration date" : "ตั้งค่าเริ่มต้นวันหมดอายุ",
+    "Expire after " : "หลังจากหมดอายุ",
+    "days" : "วัน",
+    "Enforce expiration date" : "บังคับให้มีวันที่หมดอายุ",
+    "Allow resharing" : "อนุญาตให้แชร์ข้อมูลซ้ำอีกครั้งได้",
+    "Allow sharing with groups" : "อนุญาตให้แชร์กับกลุ่ม",
+    "Restrict users to only share with users in their groups" : "จำกัดให้ผู้ใช้สามารถแชร์กับผู้ใช้ในกลุ่มของพวกเขาเท่านั้น",
+    "Exclude groups from sharing" : "ไม่รวมกลุ่มที่กำลังแชร์",
+    "These groups will still be able to receive shares, but not to initiate them." : "กลุ่มนี้จะยังคงสามารถได้รับการแชร์ แต่พวกเขาจะไม่รู้จักมัน",
+    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "อนุญาตให้เติมข้อความชื่อผู้ใช้อัตโนมัติในกล่องข้อความแชร์  ถ้านี้ถูกปิดใช้งานจะต้องกรอกชื่อผู้ใช้เอง",
+    "Tips & tricks" : "เคล็ดลับและเทคนิค",
     "How to do backups" : "วิธีการสำรองข้อมูล",
     "Advanced monitoring" : "การตรวจสอบขั้นสูง",
     "Performance tuning" : "การปรับแต่งประสิทธิภาพ",
     "Improving the config.php" : "ปรับปรุงไฟล์ config.php",
     "Theming" : "ชุดรูปแบบ",
     "Hardening and security guidance" : "คำแนะนำการรักษาความปลอดภัย",
-    "Version" : "รุ่น",
     "Developer documentation" : "เอกสารสำหรับนักพัฒนา",
-    "Experimental applications ahead" : "การใช้งานก่อนการทดลอง",
-    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "การทดลองแอพพลิเคชันไม่ได้ถูกตรวจสอบปัญหาด้านความปลอดภัย การติดตั้งพวกเขาสามารถก่อให้เกิดการสูญเสียข้อมูลหรือการละเมิดความปลอดภัย",
     "by %s" : "โดย %s",
     "%s-licensed" : "%s ได้รับใบอนุญาต",
     "Documentation:" : "เอกสาร:",
@@ -208,32 +182,26 @@ OC.L10N.register(
     "Admin documentation" : "เอกสารผู้ดูแลระบบ",
     "Show description …" : "แสดงรายละเอียด ...",
     "Hide description …" : "ซ่อนรายละเอียด ...",
-    "This app has no minimum Nextcloud version assigned. This will be an error in Nextcloud 11 and later." : "แอพฯนี้ได้ไม่บ่งบอกรุ่นต่ำสุดของ Nextcloud  นี้จะเป็นข้อผิดพลาดใน Nextcloud ที่ 11 และรุ่นต่อมา",
-    "This app has no maximum Nextcloud version assigned. This will be an error in Nextcloud 11 and later." : "แอพฯนี้ได้ไม่บ่งบอกรุ่นสูงสุดของ Nextcloud  นี้จะเป็นข้อผิดพลาดใน Nextcloud ที่ 11 และรุ่นต่อมา",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "ไม่สามารถติดตั้งแอพฯนี้เพราะไม่มีตัวอ้างอิงต่อไปนี้:",
     "Enable only for specific groups" : "เปิดใช้งานเพียงเฉพาะกลุ่ม",
     "Uninstall App" : "ถอนการติดตั้งแอพฯ",
-    "Enable experimental apps" : "เปิดใช้งานแอพพลิเคชั่นทดลอง",
     "SSL Root Certificates" : "ใบรับรอง SSL",
     "Common Name" : "ชื่อทั่วไป",
     "Valid until" : "ใช้ได้จนถึง",
     "Issued By" : "ปัญหาโดย",
     "Valid until %s" : "ใช้ได้จนถึง %s",
     "Import root certificate" : "นำเข้าใบรับรองหลัก",
-    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "นี่คุณ<br><br>อยากจะแจ้งให้คุณทราบว่าขณะนี้คุณมีบัญชี %s<br><br>ชื่อผู้ใช้ของคุณคือ: %s<br>เข้าไปงานได้ที่: <a href=\"%s\">%s</a><br><br>",
     "Cheers!" : "ไชโย!",
-    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "นี่คุณ\n\nอยากให้คุณทราบว่าขณะนี้คุณมี %s บัญชี\n\nชื่อผู้ใช้ของคุณ: %s\nดูได้ที่: %s\n",
     "Administrator documentation" : "เอกสารของผู้ดูแลระบบ",
     "Online documentation" : "เอกสารออนไลน์",
     "Forum" : "ฟอรั่ม",
-    "Issue tracker" : "ติดตามปัญหา",
     "Commercial support" : "สนับสนุนเชิงพาณิชย์",
-    "You are using <strong>%s</strong> of <strong>%s</strong>" : "คุณกำลังใช้ <strong>%s</strong> ของ <strong>%s</strong>",
+    "You are using <strong>%s</strong> of <strong>%s</strong>" : "คุณกำลังใช้พื้นที่ <strong>%s</strong> จากทั้งหมด <strong>%s</strong>",
     "Profile picture" : "รูปภาพโปรไฟล์",
     "Upload new" : "อัพโหลดใหม่",
     "Select from Files" : "เลือกจากไฟล์",
     "Remove image" : "ลบรูปภาพ",
-    "png or jpg, max. 20 MB" : "png หรือ jpg, สูงสุด 20 เมกะไบต์",
+    "png or jpg, max. 20 MB" : "จะต้องเป็นไฟล์ png หรือ jpg, สูงสุดไม่เกิน 20 เมกะไบต์",
     "Picture provided by original account" : "ใช้รูปภาพจากบัญชีเดิม",
     "Cancel" : "ยกเลิก",
     "Choose as profile picture" : "เลือกรูปภาพโปรไฟล์",
@@ -241,11 +209,10 @@ OC.L10N.register(
     "No display name set" : "ไม่มีชื่อที่แสดง",
     "Email" : "อีเมล",
     "Your email address" : "ที่อยู่อีเมล์ของคุณ",
-    "For password recovery and notifications" : "สำหรับการกู้คืนรหัสผ่านและการแจ้งเตือน",
     "No email address set" : "ไม่ได้ตั้งค่าที่อยู่อีเมล",
+    "For password recovery and notifications" : "สำหรับการกู้คืนรหัสผ่านและการแจ้งเตือน",
     "You are member of the following groups:" : "คุณเป็นสมาชิกของกลุ่มต่อไปนี้:",
     "Password" : "รหัสผ่าน",
-    "Unable to change your password" : "ไม่สามารถเปลี่ยนรหัสผ่านของคุณได้",
     "Current password" : "รหัสผ่านปัจจุบัน",
     "New password" : "รหัสผ่านใหม่",
     "Change password" : "เปลี่ยนรหัสผ่าน",
@@ -255,36 +222,56 @@ OC.L10N.register(
     "Desktop client" : "เดสก์ทอปผู้ใช้",
     "Android app" : "แอพฯ แอนดรอยด์",
     "iOS app" : "แอพฯ IOS",
-    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "หากคุณต้องการที่จะสนับสนุนโครงการ <a href=\"https://owncloud.org/contribute\" target=\"_blank\" rel=\"noreferrer\">เข้าร่วมการพัฒนา</a> หรือ <a href=\"https://owncloud.org/promote\" target=\"_blank\" rel=\"noreferrer\">กระจายข่าวสาร</a>!\n\t\t",
     "Show First Run Wizard again" : "แสดงหน้าจอวิซาร์ดนำทางครั้งแรกอีกครั้ง",
-    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "ที่พัฒนาโดย {communityopen} ชุมชน Nextcloud {linkclose} {githubopen}รหัสต้นฉบับ{linkclose} อยู่ภายใต้สัญญา {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}",
+    "Name" : "ชื่อ",
+    "Username" : "ชื่อผู้ใช้งาน",
+    "Done" : "เสร็จสิ้น",
     "Show storage location" : "แสดงสถานที่จัดเก็บข้อมูล",
     "Show last log in" : "แสดงการเข้าสู่ระบบล่าสุด",
     "Show user backend" : "แสดงแบ็กเอนด์ของผู้ใช้",
     "Send email to new user" : "ส่งอีเมลไปยังผู้ใช้ใหม่",
     "Show email address" : "แสดงที่อยู่อีเมล",
-    "Username" : "ชื่อผู้ใช้งาน",
     "E-Mail" : "อีเมล",
     "Create" : "สร้าง",
     "Admin Recovery Password" : "กู้คืนรหัสผ่านดูแลระบบ",
     "Enter the recovery password in order to recover the users files during password change" : "ป้อนรหัสผ่านการกู้คืนเพื่อกู้คืนไฟล์ผู้ใช้ในช่วงการเปลี่ยนรหัสผ่าน",
-    "Add Group" : "เพิ่มกลุ่ม",
-    "Group" : "กลุ่ม",
     "Everyone" : "ทุกคน",
     "Admins" : "ผู้ดูแลระบบ",
-    "Default Quota" : "ค่าโควต้าเริ่มต้น",
     "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "กรุณากรอกโควต้าการจัดเก็บข้อมูล (ต.ย. : \"512 MB\" หรือ \"12 GB\")",
-    "Unlimited" : "ไม่จำกัดจำนวน",
     "Other" : "อื่นๆ",
-    "Full Name" : "ชื่อเต็ม",
-    "Group Admin for" : "กลุ่มผู้ดูแลระบบสำหรับ",
     "Quota" : "โควต้า",
-    "Storage Location" : "สถานที่จัดเก็บข้อมูล",
-    "User Backend" : "ผู้ใช้แบ็กเอนด์",
-    "Last Login" : "เข้าสู่ระบบล่าสุด",
     "change full name" : "เปลี่ยนชื่อเต็ม",
     "set new password" : "ตั้งค่ารหัสผ่านใหม่",
     "change email address" : "เปลี่ยนแปลงที่อยู่อีเมล",
-    "Default" : "ค่าเริ่มต้น"
+    "Default" : "ค่าเริ่มต้น",
+    "log-level out of allowed range" : "ระดับ-บันทึก ไม่ได้อยู่ในช่วงที่ได้รับอนุญาต",
+    "Language changed" : "เปลี่ยนภาษาเรียบร้อยแล้ว",
+    "Are you really sure you want add \"{domain}\" as trusted domain?" : "คุณแน่ใจจริงๆ ว่าคุณต้องการเพิ่ม \"{domain}\" เป็นโดเมนที่เชื่อถือได้?",
+    "Everything (fatal issues, errors, warnings, info, debug)" : "ทุกอย่าง (ปัญหาร้ายแรง ข้อผิดพลาด คำเตือน ข้อมูล การแก้ปัญหา)",
+    "Info, warnings, errors and fatal issues" : "ข้อมูล คำเตือน ข้อผิดพลาดและปัญหาร้ายแรง",
+    "Warnings, errors and fatal issues" : "คำเตือนข้อผิดพลาดและปัญหาที่ร้ายแรง",
+    "Errors and fatal issues" : "ข้อผิดพลาดและปัญหาที่ร้ายแรง",
+    "Fatal issues only" : "ปัญหาร้ายแรงเท่านั้น",
+    "Log" : "บันทึกการเปลี่ยนแปลง",
+    "What to log" : "อะไรที่จะบันทึก",
+    "Download logfile" : "ดาวน์โหลดไฟล์บันทึก",
+    "More" : "มาก",
+    "Less" : "ย่อ",
+    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "ไฟล์บันทึกมีขนาดใหญ่กว่า 100 เมกะไบต์ มันอาจจะใช้เวลาดาวน์โหลดนาน!",
+    "Allow users to send mail notification for shared files" : "อนุญาตให้ผู้ใช้ส่งการแจ้งเตือนอีเมลสำหรับไฟล์ที่ถูกแชร์",
+    "Allow users to send mail notification for shared files to other users" : "อนุญาตให้ผู้ใช้ส่งการแจ้งเตือนอีเมลสำหรับไฟล์ที่แชร์กับผู้ใช้อื่นๆ",
+    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "จะใช้ SQLite เป็นฐานข้อมูล สำหรับการติดตั้งขนาดใหญ่เราขอแนะนำเพื่อสลับไปยังฐานข้อมูลแบ็กเอนด์ที่แตกต่างกัน",
+    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "โดยเฉพาะอย่างยิ่งเมื่อใช้ไคลเอนต์เดสก์ทอปสำหรับการประสานข้อมูลโดย SQLite",
+    "Experimental applications ahead" : "การใช้งานก่อนการทดลอง",
+    "Experimental apps are not checked for security issues, new or known to be unstable and under heavy development. Installing them can cause data loss or security breaches." : "การทดลองแอพพลิเคชันไม่ได้ถูกตรวจสอบปัญหาด้านความปลอดภัย การติดตั้งพวกเขาสามารถก่อให้เกิดการสูญเสียข้อมูลหรือการละเมิดความปลอดภัย",
+    "Enable experimental apps" : "เปิดใช้งานแอพพลิเคชั่นทดลอง",
+    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "นี่คุณ<br><br>อยากจะแจ้งให้คุณทราบว่าขณะนี้คุณมีบัญชี %s<br><br>ชื่อผู้ใช้ของคุณคือ: %s<br>เข้าไปงานได้ที่: <a href=\"%s\">%s</a><br><br>",
+    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "นี่คุณ\n\nอยากให้คุณทราบว่าขณะนี้คุณมี %s บัญชี\n\nชื่อผู้ใช้ของคุณ: %s\nดูได้ที่: %s\n",
+    "Group" : "กลุ่ม",
+    "APCu" : "APCu",
+    "Redis" : "Redis",
+    "External Storage" : "พื้นทีจัดเก็บข้อมูลจากภายนอก",
+    "Updates" : "อัพเดท",
+    "An error occurred: {message}" : "เกิดข้อผิดพลาด: {message}"
 },
 "nplurals=1; plural=0;");
