@@ -1,4 +1,6 @@
-<?php if (OC_Util::getEditionString() === ''): ?>
+<?php
+/** @var \OCP\IL10N $l */
+if (OC_Util::getEditionString() === ''): ?>
 	<p>
 		<?php print_unescaped(str_replace(
 			[
@@ -8,12 +10,12 @@
 				'{linkclose}',
 			],
 			[
-				'<a href="https://nextcloud.com/contact" target="_blank" rel="noreferrer">',
+				'<a href="https://nextcloud.com/contribute" target="_blank" rel="noreferrer">',
 				'<a href="https://github.com/nextcloud" target="_blank" rel="noreferrer">',
 				'<a href="https://www.gnu.org/licenses/agpl-3.0.html" target="_blank" rel="noreferrer">',
 				'</a>',
 			],
-			$l->t('Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title="Affero General Public License">AGPL</abbr>{linkclose}.')
+			$l->t('Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}.')
 		)); ?>
 	</p>
 <?php endif; ?>
